searchData={"items":[{"type":"module","title":"Aura","doc":"An ergonomic library for investigating the Hex.pm API","ref":"Aura.html"},{"type":"module","title":"Table of Contents - Aura","doc":"- [Installation](#module-installation)\n- [Configuration](#module-configuration)\n- [Smoke Test](#module-smoke-test)\n- [Implementation Overview](#module-implementation-overview)\n    - [Domains](#module-domains)\n- [Testing](#module-testing)\n- [FAQ](#module-faq)","ref":"Aura.html#module-table-of-contents"},{"type":"module","title":"Installation - Aura","doc":"Add `:aura` to your list of deps in `mix.exs`:\n\n```elixir\n{:aura, \"~> 1.0\"}\n```\n\nThen run `mix deps.get` to install Aura and its dependencies.","ref":"Aura.html#module-installation"},{"type":"module","title":"Configuration - Aura","doc":"```elixir\nconfig :aura,\n  # The hex-compliant backend for Aura to connect to\n  # This can also be passed in as an option to all service functions\n  # Default: https://hex.pm/api\n  # See \"Testing\" for other options\n  repo_url: System.get_env(\"AURA_REPO_URL\", \"http://localhost:4000/api\"),\n  # API secret payload to use when making requests from the hex-compliant backend\n  # This cannot be passed in as an option to service functions.\n  # Please: Don't put the actual secret payload as plain text in your code.\n  # Default: nil\n  api_key: System.get_env(\"HEX_API_KEY\")\n\n```","ref":"Aura.html#module-configuration"},{"type":"module","title":"Smoke Test - Aura","doc":"```elixir\n# Grab aura\n{:ok, package} = Aura.Packages.get_package(\"aura\")\nlatest_version = package.releases |> hd() |> Map.get(:version)\n# Grab aura's latest release\n{:ok, release} = Aura.Releases.get_release(\"aura\", latest_version)\n{:ok,\n %Aura.Model.HexRelease{\n   checksum: \"8fb6919a3cf545b10e09bc9b98169cca82468157a5e6b1ebd754e833934b02dd\",\n   configs: %{\n     \"erlang.mk\" => \"dep_aura = hex 0.9.1\",\n     \"mix.exs\" => \"{:aura, \\\"~> 0.9.1\\\"}\",\n     \"rebar.config\" => \"{aura, \\\"0.9.1\\\"}\"\n   },\n   docs_html_url: \"https://hexdocs.pm/aura/0.9.1/\",\n   has_docs: true,\n   html_url: \"https://hex.pm/packages/aura/0.9.1\",\n   inserted_at: ~U[2025-06-04 04:51:30.142335Z],\n   meta: %{elixir: \"~> 1.18\", app: \"aura\", build_tools: [\"mix\"]},\n   package_url: \"https://hex.pm/api/packages/aura\",\n   publisher: %{\n     url: \"https://hex.pm/api/users/camatcode\",\n     email: \"cam.cook.codes@gmail.com\",\n     username: \"camatcode\"\n   },\n   requirements: [\n     %{app: \"date_time_parser\", optional: false, requirement: \"~> 1.2.0\"},\n     %{app: \"proper_case\", optional: false, requirement: \"~> 1.3\"},\n     %{app: \"req\", optional: false, requirement: \"~> 0.5.10\"}\n   ],\n   retirement: nil,\n   updated_at: ~U[2025-06-04 04:51:33.602905Z],\n   version: \"0.9.1\",\n   url: \"https://hex.pm/api/packages/aura/releases/0.9.1\",\n   downloads: 0\n }}\n```","ref":"Aura.html#module-smoke-test"},{"type":"module","title":"Implementation Overview - Aura","doc":"","ref":"Aura.html#module-implementation-overview"},{"type":"module","title":"Domains - Aura","doc":"| Domain       | Hex API Controller                                                                                                          | Aura Equivalant | Implemented Actions                             | Notes                                       |\n|--------------|-----------------------------------------------------------------------------------------------------------------------------|-----------------|-------------------------------------------------|---------------------------------------------|\n| API Key      | [KeyController](https://github.com/hexpm/hexpm/blob/main/lib/hexpm_web/controllers/api/key_controller.ex)                   | `Aura.APIKeys`  | list, get, create, delete, delete all           | Can be scoped to an organization            |\n| Organization | [OrganizationController](https://github.com/hexpm/hexpm/blob/main/lib/hexpm_web/controllers/api/organization_controller.ex) | `Aura.Orgs`     | list, get, audit                                |                                             |\n| ∟ Org User   | [OrganizationUser](https://github.com/hexpm/hexpm/blob/main/lib/hexpm_web/controllers/api/organization_user_controller.ex)  | \"               | list, get, add, change role, remove             |                                             |\n| Package      | [PackageController](https://github.com/hexpm/hexpm/blob/main/lib/hexpm_web/controllers/api/package_controller.ex)           | `Aura.Packages` | stream packages, get, audit                     | Can be scoped to a repo                     |\n| ∟ Owner      | [OwnerController](https://github.com/hexpm/hexpm/blob/main/lib/hexpm_web/controllers/api/owner_controller.ex)               | \"               | list, get, add, remove                          | Can be scoped to a repo                     |\n| Release      | [ReleaseController](https://github.com/hexpm/hexpm/blob/main/lib/hexpm_web/controllers/api/release_controller.ex)           | `Aura.Releases` | publish, get, retire, un-retire, delete         | Can be scoped to a repo                     |\n| ∟ Doc        | [DocsController](https://github.com/hexpm/hexpm/blob/main/lib/hexpm_web/controllers/api/docs_controller.ex)                 | \"               | publish, get, delete                            | Can be scoped to a repo                     |\n| Repository   | [RepositoryController](https://github.com/hexpm/hexpm/blob/main/lib/hexpm_web/controllers/api/repository_controller.ex)     | `Aura.Repos`    | list, get                                       |                                             |\n| User         | [UserController](https://github.com/hexpm/hexpm/blob/main/lib/hexpm_web/controllers/api/user_controller.ex)                 | `Aura.Users`    | create, get, get current, reset password, audit | Read `create` docs carefully for ToS caveat |","ref":"Aura.html#module-domains"},{"type":"module","title":"Testing - Aura","doc":"> [!WARNING]\n> All Aura tests expect to connect to a local hex instance\n> and will **purposely crash** if it discovers it's testing against hex.pm.\n\nYou should be very mindful about issuing requests against a production hex API.\n\nTo make this easy, you can `docker compose up -d` from the root of this repository to launch a local instance\nof [hexpm/hexpm](https://github.com/camatcode/hex_tiny?tab=readme-ov-file#hex_beefy) and set the `repo_url`\nto http://localhost:4000/api in [Configuration](#module-configuration).\n\n```bash\n➜  docker compose up -d\n[+] Running 1/1\n ✔ Container hex_beefy  Started                                                                                  0.1s \n➜  curl http://localhost:4000/api | jq\n{\n  \"documentation_url\": \"http://docs.hexpm.apiary.io\",\n  \"key_url\": \"http://localhost:4000/api/keys/{name}\",\n  \"keys_url\": \"http://localhost:4000/api/keys\",\n  \"package_owners_url\": \"http://localhost:4000/api/packages/{name}/owners\",\n  \"package_release_url\": \"http://localhost:4000/api/packages/{name}/releases/{version}\",\n  \"package_url\": \"http://localhost:4000/api/packages/{name}\",\n  \"packages_url\": \"http://localhost:4000/api/packages\"\n}\n```","ref":"Aura.html#module-testing"},{"type":"module","title":"FAQ - Aura","doc":"> Why?\n\nI started this project while exploring all the Hex API does, had trouble understanding it all, so started documenting things as I found them, and wound up with an entire project.\n\nHere are some goals and motivations: \n\n1. Aura is meant to be friendly to Elixir folks.\n2. Aura's aim is to be [documented](https://hexdocs.pm/aura) *to hell and back*.\n3. The maintainer has larger plans that would use Aura as a base.","ref":"Aura.html#module-faq"},{"type":"module","title":"Aura.APIKeys","doc":"Service module for interacting with Hex API keys","ref":"Aura.APIKeys.html"},{"type":"module","title":"Resources - Aura.APIKeys","doc":"* Hex\n    * 📖 [Hex API Specifications](https://github.com/hexpm/specifications){:target=\"_blank\"}\n    * 👾 [Github: hexpm/hex_core](https://github.com/hexpm/hex_core){:target=\"_blank\"}\n    * 👾 [Github: hexpm/hexpm](https://github.com/hexpm/hexpm){:target=\"_blank\"}\n  * Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * ⚗️ [Elixir Form: camatcode](https://elixirforum.com/u/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    * 🦋️ [bsky: @ckcook.studiocms.io](https://bsky.app/profile/ckcook.studiocms.io){:target=\"_blank\"}","ref":"Aura.APIKeys.html#module-resources"},{"type":"type","title":"Aura.APIKeys.api_key_opts/0","doc":"Options to modify a request","ref":"Aura.APIKeys.html#t:api_key_opts/0"},{"type":"type","title":"Keys - Aura.APIKeys.api_key_opts/0","doc":"* **repo_url** :: `t:Aura.Common.repo_url/0`\n* **org** :: `t:Aura.Common.org_name/0`","ref":"Aura.APIKeys.html#t:api_key_opts/0-keys"},{"type":"function","title":"Aura.APIKeys.create_api_key/5","doc":"Creates a new API key\n\n\n\n###  Parameters \n  \n| Parameter | Description   |\n|--------|-----------------------|\n| *key_name*   | `t:Aura.Common.api_key_name/0` |\n| *username*   | `t:Aura.Common.username/0` |\n| *password*   | password for this user |\n| *allow_write*   | whether the key has `write` permissions on the `api` domain. Default: `false` |\n| `opts[:org]`   | `t:Aura.Common.org_name/0` |\n| `opts[:repo_url]`   | `t:Aura.Common.repo_url/0` |","ref":"Aura.APIKeys.html#create_api_key/5"},{"type":"function","title":"API Details - Aura.APIKeys.create_api_key/5","doc":"| Method | Path                  | Controller                                        | Action      |\n|--------|-----------------------|---------------------------------------------------|-------------|\n| **POST**    | /keys | [KeyController](https://github.com/hexpm/hexpm/blob/main/lib/hexpm_web/controllers/api/key_controller.ex){:target=\"_blank\"} | `:create` |\n| **POST**    | /orgs/`opts[:org]`/keys | [KeyController](https://github.com/hexpm/hexpm/blob/main/lib/hexpm_web/controllers/api/key_controller.ex){:target=\"_blank\"} | `:create` |","ref":"Aura.APIKeys.html#create_api_key/5-api-details"},{"type":"function","title":"Examples - Aura.APIKeys.create_api_key/5","doc":"```elixir\niex> alias Aura.APIKeys\niex> key_name = \"test_user_key\"\niex> username = \"test@test.com\"\niex> password = \"elixir1234\"\niex> allow_write = true\niex> opts = [repo_url: \"http://localhost:4000/api\"]\niex> {:ok, _key} =\n...>  APIKeys.create_api_key(key_name, username, password, allow_write, opts)\n\n# scoped to an organization\niex> alias Aura.APIKeys\niex> key_name = \"test_user_key\"\niex> username = \"test@test.com\"\niex> password = \"elixir1234\"\niex> allow_write = true\niex> opts = [repo_url: \"http://localhost:4000/api\", org: \"test_org\"]\niex> {:ok, _key} =\n...>  APIKeys.create_api_key(key_name, username, password, allow_write, opts)\n\n```","ref":"Aura.APIKeys.html#create_api_key/5-examples"},{"type":"function","title":"Aura.APIKeys.delete_all_api_keys/1","doc":"Deletes **all** API keys for the authenticated requester\n\n\n\n###  Parameters \n  \n| Parameter | Description   |\n|--------|-----------------------|\n| `opts[:org]`   | `t:Aura.Common.org_name/0` |\n| `opts[:repo_url]`   | `t:Aura.Common.repo_url/0` |","ref":"Aura.APIKeys.html#delete_all_api_keys/1"},{"type":"function","title":"API Details - Aura.APIKeys.delete_all_api_keys/1","doc":"| Method | Path                  | Controller                                        | Action      |\n|--------|-----------------------|---------------------------------------------------|-------------|\n| **DELETE**    | /keys | [KeyController](https://github.com/hexpm/hexpm/blob/main/lib/hexpm_web/controllers/api/key_controller.ex){:target=\"_blank\"} | `:delete_all` |\n| **DELETE**    | /orgs/`opts[:org]`/keys | [KeyController](https://github.com/hexpm/hexpm/blob/main/lib/hexpm_web/controllers/api/key_controller.ex){:target=\"_blank\"} | `:delete_all` |","ref":"Aura.APIKeys.html#delete_all_api_keys/1-api-details"},{"type":"function","title":"Examples - Aura.APIKeys.delete_all_api_keys/1","doc":"```elixir\niex> alias Aura.APIKeys\niex> opts = [repo_url: \"http://localhost:4000/api\"]\niex> APIKeys.delete_all_api_keys(opts)\n:ok\n\n# scoped to an organization\niex> alias Aura.APIKeys\niex> opts = [repo_url: \"http://localhost:4000/api\", org: \"test_org\"]\niex> APIKeys.delete_all_api_keys(opts)\n:ok\n\n```","ref":"Aura.APIKeys.html#delete_all_api_keys/1-examples"},{"type":"function","title":"Aura.APIKeys.delete_api_key/2","doc":"Deletes an API key for the authenticated requester, given a **key_name**\n\n\n\n###  Parameters \n  \n| Parameter | Description   |\n|--------|-----------------------|\n| *key_name*   | `t:Aura.Common.api_key_name/0` |\n| `opts[:org]`   | `t:Aura.Common.org_name/0` |\n| `opts[:repo_url]`   | `t:Aura.Common.repo_url/0` |","ref":"Aura.APIKeys.html#delete_api_key/2"},{"type":"function","title":"API Details - Aura.APIKeys.delete_api_key/2","doc":"| Method | Path                  | Controller                                        | Action      |\n|--------|-----------------------|---------------------------------------------------|-------------|\n| **DELETE**    | /keys/`:key_name` | [KeyController](https://github.com/hexpm/hexpm/blob/main/lib/hexpm_web/controllers/api/key_controller.ex){:target=\"_blank\"} | `:delete` |\n| **DELETE**    | /orgs/`opts[:org]`/keys/`:key_name` | [KeyController](https://github.com/hexpm/hexpm/blob/main/lib/hexpm_web/controllers/api/key_controller.ex){:target=\"_blank\"} | `:delete` |","ref":"Aura.APIKeys.html#delete_api_key/2-api-details"},{"type":"function","title":"Examples - Aura.APIKeys.delete_api_key/2","doc":"```elixir\niex> alias Aura.APIKeys\niex> opts = [repo_url: \"http://localhost:4000/api\"]\niex> {:ok, [key | _]} = APIKeys.list_api_keys(opts)\niex> APIKeys.delete_api_key(key.name, opts)\n:ok\n\n# scoped to an organization\niex> alias Aura.APIKeys\niex> opts = [repo_url: \"http://localhost:4000/api\", org: \"test_org\"]\niex> {:ok, [key | _]} = APIKeys.list_api_keys(opts)\niex> APIKeys.delete_api_key(key.name, opts)\n:ok\n\n```","ref":"Aura.APIKeys.html#delete_api_key/2-examples"},{"type":"function","title":"Aura.APIKeys.get_api_key/2","doc":"Grabs API key information associated with a given **key_name**\n\n\n\n###  Parameters \n  \n| Parameter | Description   |\n|--------|-----------------------|\n| *key_name*   | `t:Aura.Common.api_key_name/0` |\n| `opts[:org]`   | `t:Aura.Common.org_name/0` |\n| `opts[:repo_url]`   | `t:Aura.Common.repo_url/0` |","ref":"Aura.APIKeys.html#get_api_key/2"},{"type":"function","title":"API Details - Aura.APIKeys.get_api_key/2","doc":"| Method | Path                  | Controller                                        | Action      |\n|--------|-----------------------|---------------------------------------------------|-------------|\n| **GET**    | /keys/`:key_name` | [KeyController](https://github.com/hexpm/hexpm/blob/main/lib/hexpm_web/controllers/api/key_controller.ex){:target=\"_blank\"} | `:show` |\n| **GET**    | /orgs/`opts[:org]`/keys/`:key_name` | [KeyController](https://github.com/hexpm/hexpm/blob/main/lib/hexpm_web/controllers/api/key_controller.ex){:target=\"_blank\"} | `:show` |","ref":"Aura.APIKeys.html#get_api_key/2-api-details"},{"type":"function","title":"Examples - Aura.APIKeys.get_api_key/2","doc":"```elixir\niex> alias Aura.APIKeys\niex> opts = [repo_url: \"http://localhost:4000/api\"]\niex> {:ok, keys} = APIKeys.list_api_keys(opts)\niex> keys |> Enum.map(fn key ->  {:ok, _k} = APIKeys.get_api_key(key.name, opts) end)\n\n# scoped to an organization\niex> opts = [repo_url: \"http://localhost:4000/api\", org: \"test_org\"]\niex> {:ok, keys} = APIKeys.list_api_keys(opts)\niex> keys |> Enum.map(fn key ->  {:ok, _k} = APIKeys.get_api_key(key.name, opts) end)\n\n```","ref":"Aura.APIKeys.html#get_api_key/2-examples"},{"type":"function","title":"Aura.APIKeys.list_api_keys/1","doc":"Grabs info about the requester's API key(s)\n\n\n\n###  Parameters \n  \n| Parameter | Description   |\n|--------|-----------------------|\n| `opts[:org]`   | `t:Aura.Common.org_name/0` |\n| `opts[:repo_url]`   | `t:Aura.Common.repo_url/0` |","ref":"Aura.APIKeys.html#list_api_keys/1"},{"type":"function","title":"API Details - Aura.APIKeys.list_api_keys/1","doc":"| Method | Path                  | Controller                                        | Action      |\n|--------|-----------------------|---------------------------------------------------|-------------|\n| **GET**    | /keys | [KeyController](https://github.com/hexpm/hexpm/blob/main/lib/hexpm_web/controllers/api/key_controller.ex){:target=\"_blank\"} | `:index` |\n| **GET**    | /orgs/`opts[:org]`/keys | [KeyController](https://github.com/hexpm/hexpm/blob/main/lib/hexpm_web/controllers/api/key_controller.ex){:target=\"_blank\"} | `:index` |","ref":"Aura.APIKeys.html#list_api_keys/1-api-details"},{"type":"function","title":"Examples - Aura.APIKeys.list_api_keys/1","doc":"```elixir\niex> alias Aura.APIKeys\niex> opts = [repo_url: \"http://localhost:4000/api\"]\niex> {:ok, keys} = APIKeys.list_api_keys(opts)\niex> Enum.empty?(keys)\nfalse\n\n# scoped to an organization\niex> opts = [repo_url: \"http://localhost:4000/api\", org: \"test_org\"]\niex> {:ok, keys} = APIKeys.list_api_keys(opts)\niex> Enum.empty?(keys)\nfalse\n\n```","ref":"Aura.APIKeys.html#list_api_keys/1-examples"},{"type":"module","title":"Aura.Orgs","doc":"Service module for interacting with Hex Organizations","ref":"Aura.Orgs.html"},{"type":"module","title":"Resources - Aura.Orgs","doc":"* Hex\n    * 📖 [Hex API Specifications](https://github.com/hexpm/specifications){:target=\"_blank\"}\n    * 👾 [Github: hexpm/hex_core](https://github.com/hexpm/hex_core){:target=\"_blank\"}\n    * 👾 [Github: hexpm/hexpm](https://github.com/hexpm/hexpm){:target=\"_blank\"}\n  * Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * ⚗️ [Elixir Form: camatcode](https://elixirforum.com/u/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    * 🦋️ [bsky: @ckcook.studiocms.io](https://bsky.app/profile/ckcook.studiocms.io){:target=\"_blank\"}","ref":"Aura.Orgs.html#module-resources"},{"type":"function","title":"Aura.Orgs.add_org_member/4","doc":"Adds a user to an org with a given **role**\n\n\n\n###  Parameters \n  \n| Parameter | Description   |\n|--------|-----------------------|\n| *org_name*   | `t:Aura.Common.org_name/0` |\n| *username*   | `t:Aura.Common.username/0` |\n| *role*   | `t:Aura.Model.HexOrgMember.role/0` |\n| `opts[:repo_url]`   | `t:Aura.Common.repo_url/0` |","ref":"Aura.Orgs.html#add_org_member/4"},{"type":"function","title":"API Details - Aura.Orgs.add_org_member/4","doc":"| Method | Path                  | Controller                                        | Action      |\n|--------|-----------------------|---------------------------------------------------|-------------|\n| **POST**    | /orgs/`:org_name`/members | [OrganizationUserController](https://github.com/hexpm/hexpm/blob/main/lib/hexpm_web/controllers/api/organization_user_controller.ex){:target=\"_blank\"} | `:create` |","ref":"Aura.Orgs.html#add_org_member/4-api-details"},{"type":"function","title":"Aura.Orgs.change_member_role/4","doc":"Changes a user's role to **new_role**\n\n\n\n###  Parameters \n  \n| Parameter | Description   |\n|--------|-----------------------|\n| *org_name*   | `t:Aura.Common.org_name/0` |\n| *username*   | `t:Aura.Common.username/0` |\n| *new_role*   | `t:Aura.Model.HexOrgMember.role/0` |\n| `opts[:repo_url]`   | `t:Aura.Common.repo_url/0` |","ref":"Aura.Orgs.html#change_member_role/4"},{"type":"function","title":"API Details - Aura.Orgs.change_member_role/4","doc":"| Method | Path                  | Controller                                        | Action      |\n|--------|-----------------------|---------------------------------------------------|-------------|\n| **POST**    | /orgs/`:org_name`/members/`:username` | [OrganizationUserController](https://github.com/hexpm/hexpm/blob/main/lib/hexpm_web/controllers/api/organization_user_controller.ex){:target=\"_blank\"} | `:update` |","ref":"Aura.Orgs.html#change_member_role/4-api-details"},{"type":"function","title":"Aura.Orgs.get_org/2","doc":"Grabs an organization, given an **org_name**\n\n\n\n###  Parameters \n  \n| Parameter | Description   |\n|--------|-----------------------|\n| *org_name*   | `t:Aura.Common.org_name/0` |\n| `opts[:repo_url]`   | `t:Aura.Common.repo_url/0` |","ref":"Aura.Orgs.html#get_org/2"},{"type":"function","title":"API Details - Aura.Orgs.get_org/2","doc":"| Method | Path                  | Controller                                        | Action      |\n|--------|-----------------------|---------------------------------------------------|-------------|\n| **GET**    | /orgs/`:org_name` | [OrganizationController](https://github.com/hexpm/hexpm/blob/main/lib/hexpm_web/controllers/api/organization_controller.ex){:target=\"_blank\"} | `:show` |","ref":"Aura.Orgs.html#get_org/2-api-details"},{"type":"function","title":"Examples - Aura.Orgs.get_org/2","doc":"```elixir\niex> alias Aura.Orgs\niex> opts = [repo_url: \"http://localhost:4000/api\"]\niex> {:ok, org} = Orgs.get_org(\"test_org\", opts)\niex> org.name\n\"test_org\"\n\n```","ref":"Aura.Orgs.html#get_org/2-examples"},{"type":"function","title":"Aura.Orgs.get_org_member/3","doc":"Grabs an org member, given their **org_name** and **username**\n\n\n\n###  Parameters \n  \n| Parameter | Description   |\n|--------|-----------------------|\n| *org_name*   | `t:Aura.Common.org_name/0` |\n| *username*   | `t:Aura.Common.username/0` |\n| `opts[:repo_url]`   | `t:Aura.Common.repo_url/0` |","ref":"Aura.Orgs.html#get_org_member/3"},{"type":"function","title":"API Details - Aura.Orgs.get_org_member/3","doc":"| Method | Path                  | Controller                                        | Action      |\n|--------|-----------------------|---------------------------------------------------|-------------|\n| **GET**    | /orgs/`:org_name`/members/`:username` | [OrganizationUserController](https://github.com/hexpm/hexpm/blob/main/lib/hexpm_web/controllers/api/organization_user_controller.ex){:target=\"_blank\"} | `:show` |","ref":"Aura.Orgs.html#get_org_member/3-api-details"},{"type":"function","title":"Examples - Aura.Orgs.get_org_member/3","doc":"```elixir\niex> alias Aura.Orgs\niex> opts = [repo_url: \"http://localhost:4000/api\"]\niex> {:ok, member} = Orgs.get_org_member(\"test_org\", \"testuser\", opts)\niex> member.username\n\"testuser\"\n\n```","ref":"Aura.Orgs.html#get_org_member/3-examples"},{"type":"function","title":"Aura.Orgs.list_org_members/2","doc":"Grabs a list of members to an organization, given an **org_name**\n\n\n\n###  Parameters \n  \n| Parameter | Description   |\n|--------|-----------------------|\n| *org_name*   | `t:Aura.Common.org_name/0` |\n| `opts[:repo_url]`   | `t:Aura.Common.repo_url/0` |","ref":"Aura.Orgs.html#list_org_members/2"},{"type":"function","title":"API Details - Aura.Orgs.list_org_members/2","doc":"| Method | Path                  | Controller                                        | Action      |\n|--------|-----------------------|---------------------------------------------------|-------------|\n| **GET**    | /orgs/`:org_name`/members | [OrganizationUserController](https://github.com/hexpm/hexpm/blob/main/lib/hexpm_web/controllers/api/organization_user_controller.ex){:target=\"_blank\"} | `:index` |","ref":"Aura.Orgs.html#list_org_members/2-api-details"},{"type":"function","title":"Examples - Aura.Orgs.list_org_members/2","doc":"```elixir\niex> alias Aura.Orgs\niex> opts = [repo_url: \"http://localhost:4000/api\"]\niex> {:ok, members} = Orgs.list_org_members(\"test_org\", opts)\niex> Enum.empty?(members)\nfalse\n\n```","ref":"Aura.Orgs.html#list_org_members/2-examples"},{"type":"function","title":"Aura.Orgs.list_orgs/1","doc":"Lists all the organizations the requester can see\n\n\n\n###  Parameters \n  \n| Parameter | Description   |\n|--------|-----------------------|\n| `opts[:repo_url]`   | `t:Aura.Common.repo_url/0` |","ref":"Aura.Orgs.html#list_orgs/1"},{"type":"function","title":"API Details - Aura.Orgs.list_orgs/1","doc":"| Method | Path                  | Controller                                        | Action      |\n|--------|-----------------------|---------------------------------------------------|-------------|\n| **GET**    | /orgs | [OrganizationController](https://github.com/hexpm/hexpm/blob/main/lib/hexpm_web/controllers/api/organization_controller.ex){:target=\"_blank\"} | `:index` |","ref":"Aura.Orgs.html#list_orgs/1-api-details"},{"type":"function","title":"Examples - Aura.Orgs.list_orgs/1","doc":"```elixir\niex> alias Aura.Orgs\niex> opts = [repo_url: \"http://localhost:4000/api\"]\niex> {:ok, orgs} = Orgs.list_orgs(opts)\niex> Enum.empty?(orgs)\nfalse\n\n```","ref":"Aura.Orgs.html#list_orgs/1-examples"},{"type":"type","title":"Aura.Orgs.org_opts/0","doc":"Options to modify an Orgs request","ref":"Aura.Orgs.html#t:org_opts/0"},{"type":"type","title":"Keys - Aura.Orgs.org_opts/0","doc":"* **repo_url** :: `t:Aura.Common.repo_url/0`","ref":"Aura.Orgs.html#t:org_opts/0-keys"},{"type":"function","title":"Aura.Orgs.remove_org_member/3","doc":"Removes a user from an org\n\n\n\n###  Parameters \n  \n| Parameter | Description   |\n|--------|-----------------------|\n| *org_name*   | `t:Aura.Common.org_name/0` |\n| *username*   | `t:Aura.Common.username/0` |\n| `opts[:repo_url]`   | `t:Aura.Common.repo_url/0` |","ref":"Aura.Orgs.html#remove_org_member/3"},{"type":"function","title":"API Details - Aura.Orgs.remove_org_member/3","doc":"| Method | Path                  | Controller                                        | Action      |\n|--------|-----------------------|---------------------------------------------------|-------------|\n| **DELETE**    | /orgs/`:org_name`/members/`:username` | [OrganizationUserController](https://github.com/hexpm/hexpm/blob/main/lib/hexpm_web/controllers/api/organization_user_controller.ex){:target=\"_blank\"} | `:delete` |","ref":"Aura.Orgs.html#remove_org_member/3-api-details"},{"type":"function","title":"Aura.Orgs.stream_audit_logs/2","doc":"Streams audit logs, scoped to an organization\n\nNote that the page size is fixed by the API to be 100 per page.\n\n\n\n\n###  Parameters \n  \n| Parameter | Description   |\n|--------|-----------------------|\n| *org_name*   | `t:Aura.Common.org_name/0` |\n| `opts[:repo_url]`   | `t:Aura.Common.repo_url/0` |\n| `opts[:page]`   | `t:Aura.Common.start_page/0` |","ref":"Aura.Orgs.html#stream_audit_logs/2"},{"type":"function","title":"API Details - Aura.Orgs.stream_audit_logs/2","doc":"| Method | Path                  | Controller                                        | Action      |\n|--------|-----------------------|---------------------------------------------------|-------------|\n| **GET**    | /orgs/`:org_name`/audit-logs | [OrganizationController](https://github.com/hexpm/hexpm/blob/main/lib/hexpm_web/controllers/api/organization_controller.ex){:target=\"_blank\"} | `:audit_logs` |","ref":"Aura.Orgs.html#stream_audit_logs/2-api-details"},{"type":"function","title":"Examples - Aura.Orgs.stream_audit_logs/2","doc":"```elixir\niex> alias Aura.Orgs\niex> opts = [repo_url: \"http://localhost:4000/api\"]\niex> [first, _second] = Orgs.stream_audit_logs(\"test_org\", opts) |> Enum.take(2)\niex> String.starts_with?(first.user_agent, \"aura\")\ntrue\n\n```","ref":"Aura.Orgs.html#stream_audit_logs/2-examples"},{"type":"module","title":"Aura.Packages","doc":"Service module for interacting with Hex Packages","ref":"Aura.Packages.html"},{"type":"module","title":"Resources - Aura.Packages","doc":"* Hex\n    * 📖 [Hex API Specifications](https://github.com/hexpm/specifications){:target=\"_blank\"}\n    * 👾 [Github: hexpm/hex_core](https://github.com/hexpm/hex_core){:target=\"_blank\"}\n    * 👾 [Github: hexpm/hexpm](https://github.com/hexpm/hexpm){:target=\"_blank\"}\n  * Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * ⚗️ [Elixir Form: camatcode](https://elixirforum.com/u/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    * 🦋️ [bsky: @ckcook.studiocms.io](https://bsky.app/profile/ckcook.studiocms.io){:target=\"_blank\"}","ref":"Aura.Packages.html#module-resources"},{"type":"function","title":"Aura.Packages.add_package_owner/3","doc":"Adds a new owner to the list of package owners\n\n\n\n###  Parameters \n  \n| Parameter | Description   |\n|--------|-----------------------|\n| *package_name*   | `t:Aura.Common.package_name/0` |\n| *owner_email*   | `t:Aura.Common.email/0` |\n| `opts[:repo_url]`   | `t:Aura.Common.repo_url/0` |","ref":"Aura.Packages.html#add_package_owner/3"},{"type":"function","title":"API Details - Aura.Packages.add_package_owner/3","doc":"| Method | Path                  | Controller                                        | Action      |\n|--------|-----------------------|---------------------------------------------------|-------------|\n| **PUT**    | /packages/`:package_name`/owners/`:owner_email` | [OwnerController](https://github.com/hexpm/hexpm/blob/main/lib/hexpm_web/controllers/api/owner_controller.ex){:target=\"_blank\"} | `:create` |\n| **PUT**    | /repos/`opts[:repo]`/packages/`:package_name`/owners/`:owner_email` | [OwnerController](https://github.com/hexpm/hexpm/blob/main/lib/hexpm_web/controllers/api/owner_controller.ex){:target=\"_blank\"} | `:create` |","ref":"Aura.Packages.html#add_package_owner/3-api-details"},{"type":"function","title":"Aura.Packages.get_package/2","doc":"Grabs a package given its name\n\n\n\n###  Parameters \n  \n| Parameter | Description   |\n|--------|-----------------------|\n| *name*   | `t:Aura.Common.package_name/0` |\n| `opts[:repo_url]`   | `t:Aura.Common.repo_url/0` |","ref":"Aura.Packages.html#get_package/2"},{"type":"function","title":"API Details - Aura.Packages.get_package/2","doc":"| Method | Path                  | Controller                                        | Action      |\n|--------|-----------------------|---------------------------------------------------|-------------|\n| **GET**    | /packages/`:name` | [PackageController](https://github.com/hexpm/hexpm/blob/main/lib/hexpm_web/controllers/api/package_controller.ex){:target=\"_blank\"} | `:show` |\n| **GET**    | /repos/`opts[:repo]`/packages/`:name` | [PackageController](https://github.com/hexpm/hexpm/blob/main/lib/hexpm_web/controllers/api/package_controller.ex){:target=\"_blank\"} | `:show` |","ref":"Aura.Packages.html#get_package/2-api-details"},{"type":"function","title":"Examples - Aura.Packages.get_package/2","doc":"```elixir\niex> alias Aura.Packages\niex> {:ok, pkg} = Packages.get_package(\"decimal\", repo_url: \"http://localhost:4000/api\")\niex> pkg.name\n\"decimal\"\n\n```","ref":"Aura.Packages.html#get_package/2-examples"},{"type":"function","title":"Aura.Packages.get_package_owner/3","doc":"Grabs a single package owner by their username\n\n\n\n###  Parameters \n  \n| Parameter | Description   |\n|--------|-----------------------|\n| *name*   | `t:Aura.Common.package_name/0` |\n| *username*   | `t:Aura.Common.username/0` |\n| `opts[:repo_url]`   | `t:Aura.Common.repo_url/0` |","ref":"Aura.Packages.html#get_package_owner/3"},{"type":"function","title":"API Details - Aura.Packages.get_package_owner/3","doc":"| Method | Path                  | Controller                                        | Action      |\n|--------|-----------------------|---------------------------------------------------|-------------|\n| **GET**    | /packages/`:package_name`/owners/`:username` | [OwnerController](https://github.com/hexpm/hexpm/blob/main/lib/hexpm_web/controllers/api/owner_controller.ex){:target=\"_blank\"} | `:show` |\n| **GET**    | /repos/`opts[:repo]`/packages/`:package_name`/owners/`:username` | [OwnerController](https://github.com/hexpm/hexpm/blob/main/lib/hexpm_web/controllers/api/owner_controller.ex){:target=\"_blank\"} | `:show` |","ref":"Aura.Packages.html#get_package_owner/3-api-details"},{"type":"function","title":"Examples - Aura.Packages.get_package_owner/3","doc":"```elixir\niex> alias Aura.Packages\niex> {:ok, owner} = Packages.get_package_owner(\"decimal\", \"eric\", repo_url: \"http://localhost:4000/api\")\niex> owner.email\n\"eric@example.com\"\n\n```","ref":"Aura.Packages.html#get_package_owner/3-examples"},{"type":"function","title":"Aura.Packages.list_package_owners/2","doc":"Grabs all owners of a given package\n\n\n\n###  Parameters \n  \n| Parameter | Description   |\n|--------|-----------------------|\n| *name*   | `t:Aura.Common.package_name/0` |\n| `opts[:repo_url]`   | `t:Aura.Common.repo_url/0` |","ref":"Aura.Packages.html#list_package_owners/2"},{"type":"function","title":"API Details - Aura.Packages.list_package_owners/2","doc":"| Method | Path                  | Controller                                        | Action      |\n|--------|-----------------------|---------------------------------------------------|-------------|\n| **GET**    | /packages/`:name`/owners | [OwnerController](https://github.com/hexpm/hexpm/blob/main/lib/hexpm_web/controllers/api/owner_controller.ex){:target=\"_blank\"} | `:index` |\n| **GET**    | /repos/`opts[:repo]`/packages/`:name`/owners | [OwnerController](https://github.com/hexpm/hexpm/blob/main/lib/hexpm_web/controllers/api/owner_controller.ex){:target=\"_blank\"} | `:index` |","ref":"Aura.Packages.html#list_package_owners/2-api-details"},{"type":"function","title":"Examples - Aura.Packages.list_package_owners/2","doc":"```elixir\niex> alias Aura.Packages\niex> {:ok, [owner | _]} =\n...>   Packages.list_package_owners(\"decimal\", repo_url: \"http://localhost:4000/api\")\niex> owner.email\n\"eric@example.com\"\n\n```","ref":"Aura.Packages.html#list_package_owners/2-examples"},{"type":"type","title":"Aura.Packages.per_page/0","doc":"The number of results per internal page. Aura sets this to 1000.","ref":"Aura.Packages.html#t:per_page/0"},{"type":"type","title":"Aura.Packages.pkg_opts/0","doc":"Options to modify a Packages request","ref":"Aura.Packages.html#t:pkg_opts/0"},{"type":"type","title":"Keys - Aura.Packages.pkg_opts/0","doc":"* **repo_url** :: `t:Aura.Common.repo_url/0`","ref":"Aura.Packages.html#t:pkg_opts/0-keys"},{"type":"type","title":"Aura.Packages.pkg_stream_opts/0","doc":"Options to modify a Package stream request","ref":"Aura.Packages.html#t:pkg_stream_opts/0"},{"type":"type","title":"Keys - Aura.Packages.pkg_stream_opts/0","doc":"* **sort** :: `t:Aura.Packages.sort_order/0`\n* **search** :: `t:Aura.Packages.search_term/0`\n* **repo_url** :: `t:Aura.Common.repo_url/0`\n* **repo** :: `t:Aura.Common.repo_name/0`\n* **page** :: `t:Aura.Common.start_page/0`\n* **per_page** :: `t:Aura.Packages.per_page/0`","ref":"Aura.Packages.html#t:pkg_stream_opts/0-keys"},{"type":"function","title":"Aura.Packages.remove_package_owner/3","doc":"Removes an existing owner from the list of package owners\n\n\n\n###  Parameters \n  \n| Parameter | Description   |\n|--------|-----------------------|\n| *package_name*   | `t:Aura.Common.package_name/0` |\n| *owner_email*   | `t:Aura.Common.email/0` |\n| `opts[:repo_url]`   | `t:Aura.Common.repo_url/0` |","ref":"Aura.Packages.html#remove_package_owner/3"},{"type":"function","title":"API Details - Aura.Packages.remove_package_owner/3","doc":"| Method | Path                  | Controller                                        | Action      |\n|--------|-----------------------|---------------------------------------------------|-------------|\n| **DELETE**    | /packages/`:package_name`/owners/`:owner_email` | [OwnerController](https://github.com/hexpm/hexpm/blob/main/lib/hexpm_web/controllers/api/owner_controller.ex){:target=\"_blank\"} | `:delete` |\n| **DELETE**    | /repos/`opts[:repo]`/packages/`:package_name`/owners/`:owner_email` | [OwnerController](https://github.com/hexpm/hexpm/blob/main/lib/hexpm_web/controllers/api/owner_controller.ex){:target=\"_blank\"} | `:delete` |","ref":"Aura.Packages.html#remove_package_owner/3-api-details"},{"type":"type","title":"Aura.Packages.search_term/0","doc":"Search term that filters package results\n\nBy default search will do a wildcard match on the package name and full text search on the package \ndescription. If the search string is `nerves`, package names matching `*nerves*` will be found and \npackages having `nerves` or a stemmed version of the string in the description.\n\n\nSearch can also be performed on specific fields, for example: `name:nerves* extra:package,name,postgresql`.\n\nThe search fields are:\n\n* `name` - Package name, can include the wildcard operator `*` at the end or start of the string.\n* `description` - Full text search package description.\n* `extra` - Comma-separated search on `extra` map in metadata. `extra:type,nerves` will match \n`{\"type\": \"nerves\"}`.","ref":"Aura.Packages.html#t:search_term/0"},{"type":"type","title":"Aura.Packages.sort_order/0","doc":"Sorting criteria for response","ref":"Aura.Packages.html#t:sort_order/0"},{"type":"function","title":"Aura.Packages.stream_audit_logs/2","doc":"Streams audit logs, scoped to a package\n\nNote that the page size is fixed by the API to be 100 per page.\n\n\n\n\n###  Parameters \n  \n| Parameter | Description   |\n|--------|-----------------------|\n| *package_name*   | `t:Aura.Common.package_name/0` |\n| `opts[:repo_url]`   | `t:Aura.Common.repo_url/0` |\n| `opts[:page]`   | `t:Aura.Common.start_page/0` |","ref":"Aura.Packages.html#stream_audit_logs/2"},{"type":"function","title":"API Details - Aura.Packages.stream_audit_logs/2","doc":"| Method | Path                  | Controller                                        | Action      |\n|--------|-----------------------|---------------------------------------------------|-------------|\n| **GET**    | /packages/`:package_name`/audit-logs | [PackageController](https://github.com/hexpm/hexpm/blob/main/lib/hexpm_web/controllers/api/package_controller.ex){:target=\"_blank\"} | `:audit_logs` |\n| **GET**    | /repos/`opts[:repo]`/packages/`:package_name`/audit-logs | [PackageController](https://github.com/hexpm/hexpm/blob/main/lib/hexpm_web/controllers/api/package_controller.ex){:target=\"_blank\"} | `:audit_logs` |","ref":"Aura.Packages.html#stream_audit_logs/2-api-details"},{"type":"function","title":"Examples - Aura.Packages.stream_audit_logs/2","doc":"```elixir\niex> alias Aura.Packages\niex> opts = [repo_url: \"http://localhost:4000/api\"]\niex> audit_logs = Packages.stream_audit_logs(\"decimal\", opts) |> Enum.take(20)\niex> _actions = Enum.map(audit_logs, fn audit_log -> audit_log.action end)\n\n```","ref":"Aura.Packages.html#stream_audit_logs/2-examples"},{"type":"function","title":"Aura.Packages.stream_packages/1","doc":"Grabs a stream of packages, given optional criteria\n\n\n\n###  Parameters \n  \n| Parameter | Description   |\n|--------|-----------------------|\n| `opts[:repo_url]`   | `t:Aura.Common.repo_url/0` |\n| `opts[:page]`   | `t:Aura.Common.start_page/0` |\n| `opts[:per_page]`   | `t:Aura.Packages.per_page/0` |\n| `opts[:sort]`   | `t:Aura.Packages.sort_order/0` |\n| `opts[:search]`   | `t:Aura.Packages.search_term/0` |","ref":"Aura.Packages.html#stream_packages/1"},{"type":"function","title":"API Details - Aura.Packages.stream_packages/1","doc":"| Method | Path                  | Controller                                        | Action      |\n|--------|-----------------------|---------------------------------------------------|-------------|\n| **GET**    | /packages | [PackageController](https://github.com/hexpm/hexpm/blob/main/lib/hexpm_web/controllers/api/package_controller.ex){:target=\"_blank\"} | `:index` |\n| **GET**    | /repos/`opts[:repo]`/packages | [PackageController](https://github.com/hexpm/hexpm/blob/main/lib/hexpm_web/controllers/api/package_controller.ex){:target=\"_blank\"} | `:index` |","ref":"Aura.Packages.html#stream_packages/1-api-details"},{"type":"function","title":"Examples - Aura.Packages.stream_packages/1","doc":"```elixir\n# request packages,\n#   from the local test instance\n#   scoped to the repo \"hexpm\"\n#   sorted by total downloads\n#   starting with page 2\niex> alias Aura.Packages\niex> opts = [repo_url: \"http://localhost:4000/api\", repo: \"hexpm\",\n...>         sort: :total_downloads]\niex> packages = Packages.stream_packages(\n...>  opts ++ [page: 2])\niex> Enum.empty?(packages)\nfalse\n\n# Use search term\niex> alias Aura.Packages\niex> opts = [repo_url: \"http://localhost:4000/api\", repo: \"hexpm\",\n...>         sort: :total_downloads, per_page: 5]\niex> packages = Packages.stream_packages(\n...>  opts ++ [search: \"nerves\"]) |> Enum.take(50)\niex> Enum.empty?(packages)\nfalse\n\n```","ref":"Aura.Packages.html#stream_packages/1-examples"},{"type":"module","title":"Aura.Releases","doc":"Service module for interacting with Hex package releases","ref":"Aura.Releases.html"},{"type":"module","title":"Resources - Aura.Releases","doc":"* Hex\n    * 📖 [Hex API Specifications](https://github.com/hexpm/specifications){:target=\"_blank\"}\n    * 👾 [Github: hexpm/hex_core](https://github.com/hexpm/hex_core){:target=\"_blank\"}\n    * 👾 [Github: hexpm/hexpm](https://github.com/hexpm/hexpm){:target=\"_blank\"}\n  * Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * ⚗️ [Elixir Form: camatcode](https://elixirforum.com/u/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    * 🦋️ [bsky: @ckcook.studiocms.io](https://bsky.app/profile/ckcook.studiocms.io){:target=\"_blank\"}","ref":"Aura.Releases.html#module-resources"},{"type":"function","title":"Aura.Releases.delete_release/3","doc":"Permanently deletes a release\n\n\n\n###  Parameters \n  \n| Parameter | Description   |\n|--------|-----------------------|\n| *package_name*   | `t:Aura.Common.package_name/0` |\n| *version*   | `t:Aura.Common.release_version/0` |\n| `opts[:repo]`   | `t:Aura.Common.repo_name/0` |\n| `opts[:repo_url]`   | `t:Aura.Common.repo_url/0` |","ref":"Aura.Releases.html#delete_release/3"},{"type":"function","title":"API Details - Aura.Releases.delete_release/3","doc":"| Method | Path                  | Controller                                        | Action      |\n|--------|-----------------------|---------------------------------------------------|-------------|\n| **DELETE**    | /packages/`:package_name`/releases/`:version` | [ReleaseController](https://github.com/hexpm/hexpm/blob/main/lib/hexpm_web/controllers/api/release_controller.ex){:target=\"_blank\"} | `:delete` |\n| **DELETE**    | /repos/`opts[:repo]`/packages/`:package_name`/releases/`:version` | [ReleaseController](https://github.com/hexpm/hexpm/blob/main/lib/hexpm_web/controllers/api/release_controller.ex){:target=\"_blank\"} | `:delete` |","ref":"Aura.Releases.html#delete_release/3-api-details"},{"type":"function","title":"Examples - Aura.Releases.delete_release/3","doc":"```elixir\niex> alias Aura.Releases\niex> repo_url = \"http://localhost:4000/api\"\niex> # find a release made by the test framework\niex> [package] = Enum.take(Packages.stream_packages(sort: :updated_at), 1)\niex> version = package.releases |> hd() |> Map.get(:version)\niex> # delete the release\niex> Releases.delete_release(package.name, version, repo_url: repo_url)\n:ok\n\n```","ref":"Aura.Releases.html#delete_release/3-examples"},{"type":"function","title":"Aura.Releases.delete_release_docs/3","doc":"Permanently deletes associated documentation for a release\n\n\n\n###  Parameters \n  \n| Parameter | Description   |\n|--------|-----------------------|\n| *package_name*   | `t:Aura.Common.package_name/0` |\n| *version*   | `t:Aura.Common.release_version/0` |\n| `opts[:repo]`   | `t:Aura.Common.repo_name/0` |\n| `opts[:repo_url]`   | `t:Aura.Common.repo_url/0` |","ref":"Aura.Releases.html#delete_release_docs/3"},{"type":"function","title":"API Details - Aura.Releases.delete_release_docs/3","doc":"| Method | Path                  | Controller                                        | Action      |\n|--------|-----------------------|---------------------------------------------------|-------------|\n| **DELETE**    | /packages/`:package_name`/releases/`:version`/docs | [DocsController](https://github.com/hexpm/hexpm/blob/main/lib/hexpm_web/controllers/api/docs_controller.ex){:target=\"_blank\"} | `:delete` |\n| **DELETE**    | /repos/`opts[:repo]`/packages/`:package_name`/releases/`:version`/docs | [DocsController](https://github.com/hexpm/hexpm/blob/main/lib/hexpm_web/controllers/api/docs_controller.ex){:target=\"_blank\"} | `:delete` |","ref":"Aura.Releases.html#delete_release_docs/3-api-details"},{"type":"function","title":"Examples - Aura.Releases.delete_release_docs/3","doc":"```elixir\niex> alias Aura.Releases\niex> repo_url = \"http://localhost:4000/api\"\niex> # find a release made by the test framework\niex> [package] = Enum.take(Packages.stream_packages(sort: :updated_at), 1)\niex> version = package.releases |> hd() |> Map.get(:version)\niex> # delete associated doc tar.gz\niex> Releases.delete_release_docs(\n...>           package.name,\n...>           version,\n...>           repo_url: repo_url)\n:ok\n\n```","ref":"Aura.Releases.html#delete_release_docs/3-examples"},{"type":"type","title":"Aura.Releases.download_period/0","doc":"Reporting period for the number of downloads","ref":"Aura.Releases.html#t:download_period/0"},{"type":"type","title":"Aura.Releases.get_rel_opts/0","doc":"","ref":"Aura.Releases.html#t:get_rel_opts/0"},{"type":"function","title":"Aura.Releases.get_release/3","doc":"Grabs a released package, given its name and version number\n\n\n\n###  Parameters \n  \n| Parameter | Description   |\n|--------|-----------------------|\n| *package_name*   | `t:Aura.Common.package_name/0` |\n| *version*   | `t:Aura.Common.release_version/0` |\n| `opts[:repo]`   | `t:Aura.Common.repo_name/0` |\n| `opts[:repo_url]`   | `t:Aura.Common.repo_url/0` |\n| `opts[:downloads]`   | `t:Aura.Releases.download_period/0` |","ref":"Aura.Releases.html#get_release/3"},{"type":"function","title":"API Details - Aura.Releases.get_release/3","doc":"| Method | Path                  | Controller                                        | Action      |\n|--------|-----------------------|---------------------------------------------------|-------------|\n| **GET**    | /packages/`:package_name`/releases/`:version` | [ReleaseController](https://github.com/hexpm/hexpm/blob/main/lib/hexpm_web/controllers/api/release_controller.ex){:target=\"_blank\"} | `:show` |\n| **GET**    | /repos/`opts[:repo]`/packages/`:package_name`/releases/`:version` | [ReleaseController](https://github.com/hexpm/hexpm/blob/main/lib/hexpm_web/controllers/api/release_controller.ex){:target=\"_blank\"} | `:show` |","ref":"Aura.Releases.html#get_release/3-api-details"},{"type":"function","title":"Examples - Aura.Releases.get_release/3","doc":"```elixir\niex> alias Aura.Releases\niex> repo_url = \"http://localhost:4000/api\"\niex> {:ok, postgrex} = Releases.get_release(\"postgrex\", \"0.1.0\", repo_url: repo_url)\niex> postgrex.version\n\"0.1.0\"\n\n```","ref":"Aura.Releases.html#get_release/3-examples"},{"type":"function","title":"Aura.Releases.get_release_docs/3","doc":"Returns the contents of the release's docs **tar.gz**\n\n\n\n###  Parameters \n  \n| Parameter | Description   |\n|--------|-----------------------|\n| *package_name*   | `t:Aura.Common.package_name/0` |\n| *version*   | `t:Aura.Common.release_version/0` |\n| `opts[:repo]`   | `t:Aura.Common.repo_name/0` |\n| `opts[:repo_url]`   | `t:Aura.Common.repo_url/0` |","ref":"Aura.Releases.html#get_release_docs/3"},{"type":"function","title":"API Details - Aura.Releases.get_release_docs/3","doc":"| Method | Path                  | Controller                                        | Action      |\n|--------|-----------------------|---------------------------------------------------|-------------|\n| **GET**    | /packages/`:package_name`/releases/`:version`/docs | [DocsController](https://github.com/hexpm/hexpm/blob/main/lib/hexpm_web/controllers/api/docs_controller.ex){:target=\"_blank\"} | `:show` |\n| **GET**    | /repos/`opts[:repo]`/packages/`:package_name`/releases/`:version`/docs | [DocsController](https://github.com/hexpm/hexpm/blob/main/lib/hexpm_web/controllers/api/docs_controller.ex){:target=\"_blank\"} | `:show` |","ref":"Aura.Releases.html#get_release_docs/3-api-details"},{"type":"function","title":"Examples - Aura.Releases.get_release_docs/3","doc":"```elixir\niex> alias Aura.Releases\niex> repo_url = \"http://localhost:4000/api\"\niex> {:ok, contents} = Releases.get_release_docs(\"jason\", \"1.4.4\", repo_url: repo_url)\niex> Enum.empty?(contents)\nfalse\n\n```","ref":"Aura.Releases.html#get_release_docs/3-examples"},{"type":"type","title":"Aura.Releases.publish_opts/0","doc":"","ref":"Aura.Releases.html#t:publish_opts/0"},{"type":"function","title":"Aura.Releases.publish_release/2","doc":"Publishes a release **.tar** packaged by a build tool to a Hex-compliant repository\n\n\n\n###  Parameters \n  \n| Parameter | Description   |\n|--------|-----------------------|\n| *release_code_tar*   | path to a code .tar file made by a build tool |\n| `opts[:repo]`   | `t:Aura.Common.repo_name/0` |\n| `opts[:repo_url]`   | `t:Aura.Common.repo_url/0` |\n| `opts[:replace]`   | `t:Aura.Releases.rewrite?/0` |","ref":"Aura.Releases.html#publish_release/2"},{"type":"function","title":"API Details - Aura.Releases.publish_release/2","doc":"| Method | Path                  | Controller                                        | Action      |\n|--------|-----------------------|---------------------------------------------------|-------------|\n| **POST**    | /publish | [ReleaseController](https://github.com/hexpm/hexpm/blob/main/lib/hexpm_web/controllers/api/release_controller.ex){:target=\"_blank\"} | `:publish` |\n| **POST**    | /repos/`opts[:repo]`/publish | [ReleaseController](https://github.com/hexpm/hexpm/blob/main/lib/hexpm_web/controllers/api/release_controller.ex){:target=\"_blank\"} | `:publish` |","ref":"Aura.Releases.html#publish_release/2-api-details"},{"type":"function","title":"Aura.Releases.publish_release_docs/4","doc":"Publishes associated release docs **tar.gz** to a Hex-compliant repository\n\n\n\n###  Parameters \n  \n| Parameter | Description   |\n|--------|-----------------------|\n| *package_name*   | `t:Aura.Common.package_name/0` |\n| *version*   | `t:Aura.Common.release_version/0` |\n| *doc_tar*   | path to a tar.gz of the compiled docs |\n| `opts[:repo]`   | `t:Aura.Common.repo_name/0` |\n| `opts[:repo_url]`   | `t:Aura.Common.repo_url/0` |","ref":"Aura.Releases.html#publish_release_docs/4"},{"type":"function","title":"API Details - Aura.Releases.publish_release_docs/4","doc":"| Method | Path                  | Controller                                        | Action      |\n|--------|-----------------------|---------------------------------------------------|-------------|\n| **POST**    | /packages/`:package_name`/releases/`:release_version`/docs | [DocsController](https://github.com/hexpm/hexpm/blob/main/lib/hexpm_web/controllers/api/docs_controller.ex){:target=\"_blank\"} | `:create` |\n| **POST**    | /repos/`opts[:repo]`/packages/`:package_name`/releases/`:release_version`/docs | [DocsController](https://github.com/hexpm/hexpm/blob/main/lib/hexpm_web/controllers/api/docs_controller.ex){:target=\"_blank\"} | `:create` |","ref":"Aura.Releases.html#publish_release_docs/4-api-details"},{"type":"function","title":"Examples - Aura.Releases.publish_release_docs/4","doc":"```elixir\niex> alias Aura.Releases\niex> repo_url = \"http://localhost:4000/api\"\niex> # find a release made by the test framework\niex> [package] = Enum.take(Packages.stream_packages(sort: :updated_at), 1)\niex> version = package.releases |> hd() |> Map.get(:version)\niex> doc_tar = \"test/support/data/docs/nimble_parsec-1.4.2.tar.gz\"\niex> # publish doc tar.gz\niex> {:ok, _loc} = Releases.publish_release_docs(\n...>                 package.name,\n...>                 version,\n...>                 doc_tar,\n...>                 repo_url: repo_url)\n\n```","ref":"Aura.Releases.html#publish_release_docs/4-examples"},{"type":"type","title":"Aura.Releases.rel_opts/0","doc":"","ref":"Aura.Releases.html#t:rel_opts/0"},{"type":"type","title":"Aura.Releases.retire_reason/0","doc":"The reason for retiring a release","ref":"Aura.Releases.html#t:retire_reason/0"},{"type":"function","title":"Aura.Releases.retire_release/5","doc":"Marks a release as **retired**, signaling to others that it should not be used\n\n\n\n###  Parameters \n  \n| Parameter | Description   |\n|--------|-----------------------|\n| *package_name*   | `t:Aura.Common.package_name/0` |\n| *version*   | `t:Aura.Common.release_version/0` |\n| *reason*   | `t:Aura.Releases.retire_reason/0` |\n| *message*   | Human-readable blurb about the retirement |\n| `opts[:repo]`   | `t:Aura.Common.repo_name/0` |\n| `opts[:repo_url]`   | `t:Aura.Common.repo_url/0` |","ref":"Aura.Releases.html#retire_release/5"},{"type":"function","title":"API Details - Aura.Releases.retire_release/5","doc":"| Method | Path                  | Controller                                        | Action      |\n|--------|-----------------------|---------------------------------------------------|-------------|\n| **POST**    | /packages/`:package_name`/releases/`:version`/retire | [RetirementController](https://github.com/hexpm/hexpm/blob/main/lib/hexpm_web/controllers/api/retirement_controller.ex){:target=\"_blank\"} | `:create` |\n| **POST**    | /repos/`opts[:repo]`/packages/`:package_name`/releases/`:version`/retire | [RetirementController](https://github.com/hexpm/hexpm/blob/main/lib/hexpm_web/controllers/api/retirement_controller.ex){:target=\"_blank\"} | `:create` |","ref":"Aura.Releases.html#retire_release/5-api-details"},{"type":"function","title":"Examples - Aura.Releases.retire_release/5","doc":"```elixir\niex> alias Aura.Releases\niex> repo_url = \"http://localhost:4000/api\"\niex> # find a release made by the test framework\niex> [package] = Enum.take(Packages.stream_packages(sort: :updated_at), 1)\niex> version = package.releases |> hd() |> Map.get(:version)\niex> reason = :deprecated\niex> msg = \"Release no longer supported\"\niex> # retire the release\niex> Releases.retire_release(\n...>          package.name,\n...>          version,\n...>          reason,\n...>          msg,\n...>          repo_url: repo_url)\n:ok\n\n```","ref":"Aura.Releases.html#retire_release/5-examples"},{"type":"type","title":"Aura.Releases.rewrite?/0","doc":"Whether this request is a re-write of a previously published release","ref":"Aura.Releases.html#t:rewrite?/0"},{"type":"function","title":"Aura.Releases.undo_retire_release/3","doc":"Removes **retirement** from a release, signaling to others that it can still be used\n\n\n\n###  Parameters \n  \n| Parameter | Description   |\n|--------|-----------------------|\n| *package_name*   | `t:Aura.Common.package_name/0` |\n| *version*   | `t:Aura.Common.release_version/0` |\n| `opts[:repo]`   | `t:Aura.Common.repo_name/0` |\n| `opts[:repo_url]`   | `t:Aura.Common.repo_url/0` |","ref":"Aura.Releases.html#undo_retire_release/3"},{"type":"function","title":"API Details - Aura.Releases.undo_retire_release/3","doc":"| Method | Path                  | Controller                                        | Action      |\n|--------|-----------------------|---------------------------------------------------|-------------|\n| **DELETE**    | /packages/`:package_name`/releases/`:version`/retire | [RetirementController](https://github.com/hexpm/hexpm/blob/main/lib/hexpm_web/controllers/api/retirement_controller.ex){:target=\"_blank\"} | `:delete` |\n| **DELETE**    | /repos/`opts[:repo]`/packages/`:package_name`/releases/`:version`/retire | [RetirementController](https://github.com/hexpm/hexpm/blob/main/lib/hexpm_web/controllers/api/retirement_controller.ex){:target=\"_blank\"} | `:delete` |","ref":"Aura.Releases.html#undo_retire_release/3-api-details"},{"type":"function","title":"Examples - Aura.Releases.undo_retire_release/3","doc":"```elixir\niex> alias Aura.Releases\niex> repo_url = \"http://localhost:4000/api\"\niex> # find a release made by the test framework\niex> [package] = Enum.take(Packages.stream_packages(sort: :updated_at), 1)\niex> version = package.releases |> hd() |> Map.get(:version)\niex> # undo the retirement\niex> Releases.undo_retire_release(\n...>          package.name,\n...>          version,\n...>          repo_url: repo_url)\n:ok\n\n```","ref":"Aura.Releases.html#undo_retire_release/3-examples"},{"type":"module","title":"Aura.Repos","doc":"Service module for interacting with Hex repos","ref":"Aura.Repos.html"},{"type":"module","title":"Resources - Aura.Repos","doc":"* Hex\n    * 📖 [Hex API Specifications](https://github.com/hexpm/specifications){:target=\"_blank\"}\n    * 👾 [Github: hexpm/hex_core](https://github.com/hexpm/hex_core){:target=\"_blank\"}\n    * 👾 [Github: hexpm/hexpm](https://github.com/hexpm/hexpm){:target=\"_blank\"}\n  * Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * ⚗️ [Elixir Form: camatcode](https://elixirforum.com/u/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    * 🦋️ [bsky: @ckcook.studiocms.io](https://bsky.app/profile/ckcook.studiocms.io){:target=\"_blank\"}","ref":"Aura.Repos.html#module-resources"},{"type":"function","title":"Aura.Repos.get_repo/2","doc":"Grabs a hex repo associated with a given **repo_name**\n\n\n\n###  Parameters \n  \n| Parameter | Description   |\n|--------|-----------------------|\n| *repo_name*   | `t:Aura.Common.repo_name/0` |\n| `opts[:repo_url]`   | `t:Aura.Common.repo_url/0` |","ref":"Aura.Repos.html#get_repo/2"},{"type":"function","title":"API Details - Aura.Repos.get_repo/2","doc":"| Method | Path                  | Controller                                        | Action      |\n|--------|-----------------------|---------------------------------------------------|-------------|\n| **GET**    | /repos/`:repo_name` | [RepositoryController](https://github.com/hexpm/hexpm/blob/main/lib/hexpm_web/controllers/api/repository_controller.ex){:target=\"_blank\"} | `:show` |","ref":"Aura.Repos.html#get_repo/2-api-details"},{"type":"function","title":"Examples - Aura.Repos.get_repo/2","doc":"```elixir\niex> alias Aura.Repos\niex> repo_url = \"http://localhost:4000/api\"\niex> {:ok, hexpm} = Repos.get_repo(\"hexpm\", repo_url: repo_url)\niex> hexpm.name\n\"hexpm\"\n\n```","ref":"Aura.Repos.html#get_repo/2-examples"},{"type":"function","title":"Aura.Repos.list_repos/1","doc":"Grabs hex repos that the user can see\n\n\n\n###  Parameters \n  \n| Parameter | Description   |\n|--------|-----------------------|\n| `opts[:repo_url]`   | `t:Aura.Common.repo_url/0` |","ref":"Aura.Repos.html#list_repos/1"},{"type":"function","title":"API Details - Aura.Repos.list_repos/1","doc":"| Method | Path                  | Controller                                        | Action      |\n|--------|-----------------------|---------------------------------------------------|-------------|\n| **GET**    | /repos | [RepositoryController](https://github.com/hexpm/hexpm/blob/main/lib/hexpm_web/controllers/api/repository_controller.ex){:target=\"_blank\"} | `:index` |","ref":"Aura.Repos.html#list_repos/1-api-details"},{"type":"function","title":"Examples - Aura.Repos.list_repos/1","doc":"```elixir\niex> alias Aura.Repos\niex> repo_url = \"http://localhost:4000/api\"\niex> {:ok, [hexpm |_ ]} = Repos.list_repos(repo_url: repo_url)\niex> hexpm.name\n\"hexpm\"\n\n```","ref":"Aura.Repos.html#list_repos/1-examples"},{"type":"type","title":"Aura.Repos.repo_opts/0","doc":"","ref":"Aura.Repos.html#t:repo_opts/0"},{"type":"module","title":"Aura.Users","doc":"Service module for interacting with Hex users","ref":"Aura.Users.html"},{"type":"module","title":"Resources - Aura.Users","doc":"* Hex\n    * 📖 [Hex API Specifications](https://github.com/hexpm/specifications){:target=\"_blank\"}\n    * 👾 [Github: hexpm/hex_core](https://github.com/hexpm/hex_core){:target=\"_blank\"}\n    * 👾 [Github: hexpm/hexpm](https://github.com/hexpm/hexpm){:target=\"_blank\"}\n  * Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * ⚗️ [Elixir Form: camatcode](https://elixirforum.com/u/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    * 🦋️ [bsky: @ckcook.studiocms.io](https://bsky.app/profile/ckcook.studiocms.io){:target=\"_blank\"}","ref":"Aura.Users.html#module-resources"},{"type":"function","title":"Aura.Users.create_user/4","doc":"Requests a hex user be created\n\n> #### 📄 Terms of Service {: .warning}\n>\n> If your service is using hex.pm as a backend, you **must** have users to agree to Hex's [Terms of Service](https://hex.pm/policies/termsofservice)\n\n\n\n###  Parameters \n  \n| Parameter | Description   |\n|--------|-----------------------|\n| *username*   | `t:Aura.Common.username/0` |\n| *password*   | User's password |\n| *emails*   | [`t:Aura.Common.email/0`] |\n| `opts[:repo_url]`   | `t:Aura.Common.repo_url/0` |","ref":"Aura.Users.html#create_user/4"},{"type":"function","title":"API Details - Aura.Users.create_user/4","doc":"| Method | Path                  | Controller                                        | Action      |\n|--------|-----------------------|---------------------------------------------------|-------------|\n| **POST**    | /users | [UserController](https://github.com/hexpm/hexpm/blob/main/lib/hexpm_web/controllers/api/user_controller.ex){:target=\"_blank\"} | `:create` |","ref":"Aura.Users.html#create_user/4-api-details"},{"type":"function","title":"Examples - Aura.Users.create_user/4","doc":"```elixir\niex> Application.delete_env(:aura, :api_key)\niex> username = Faker.Internet.user_name()\niex> password = Faker.Internet.slug()\niex> emails = [Faker.Internet.email()]\niex> alias Aura.Users\niex> opts = [repo_url: \"http://localhost:4000/api\"]\niex> {:ok, _user} =  Users.create_user(username, password, emails, opts)\n\n```","ref":"Aura.Users.html#create_user/4-examples"},{"type":"function","title":"Aura.Users.get_current_user/1","doc":"Grabs the hex user representing the currently authenticated user\n\n\n\n###  Parameters \n  \n| Parameter | Description   |\n|--------|-----------------------|\n| `opts[:repo_url]`   | `t:Aura.Common.repo_url/0` |","ref":"Aura.Users.html#get_current_user/1"},{"type":"function","title":"API Details - Aura.Users.get_current_user/1","doc":"| Method | Path                  | Controller                                        | Action      |\n|--------|-----------------------|---------------------------------------------------|-------------|\n| **GET**    | /users/me | [UserController](https://github.com/hexpm/hexpm/blob/main/lib/hexpm_web/controllers/api/user_controller.ex){:target=\"_blank\"} | `:me` |","ref":"Aura.Users.html#get_current_user/1-api-details"},{"type":"function","title":"Examples - Aura.Users.get_current_user/1","doc":"```elixir\niex> alias Aura.Users\niex> opts = [repo_url: \"http://localhost:4000/api\"]\niex> {:ok, _user} =  Users.get_current_user(opts)\n\n```","ref":"Aura.Users.html#get_current_user/1-examples"},{"type":"function","title":"Aura.Users.get_user/2","doc":"Grabs a hex user, given their **username_or_email**\n\n\n\n###  Parameters \n  \n| Parameter | Description   |\n|--------|-----------------------|\n| *username_or_email*   | `t:Aura.Common.username/0` or  `t:Aura.Common.email/0` |\n| `opts[:repo_url]`   | `t:Aura.Common.repo_url/0` |","ref":"Aura.Users.html#get_user/2"},{"type":"function","title":"API Details - Aura.Users.get_user/2","doc":"| Method | Path                  | Controller                                        | Action      |\n|--------|-----------------------|---------------------------------------------------|-------------|\n| **GET**    | /users/`:username_or_email` | [UserController](https://github.com/hexpm/hexpm/blob/main/lib/hexpm_web/controllers/api/user_controller.ex){:target=\"_blank\"} | `:show` |","ref":"Aura.Users.html#get_user/2-api-details"},{"type":"function","title":"Examples - Aura.Users.get_user/2","doc":"```elixir\niex> alias Aura.Users\niex> opts = [repo_url: \"http://localhost:4000/api\"]\niex> {:ok, _user} =  Users.get_user(\"eric@example.com\", opts)\n\n```","ref":"Aura.Users.html#get_user/2-examples"},{"type":"function","title":"Aura.Users.reset_user_password/2","doc":"Resets a specified user's password\n\n\n\n###  Parameters \n  \n| Parameter | Description   |\n|--------|-----------------------|\n| *username_or_email*   | `t:Aura.Common.username/0`  or  `t:Aura.Common.email/0` |\n| `opts[:repo_url]`   | `t:Aura.Common.repo_url/0` |","ref":"Aura.Users.html#reset_user_password/2"},{"type":"function","title":"API Details - Aura.Users.reset_user_password/2","doc":"| Method | Path                  | Controller                                        | Action      |\n|--------|-----------------------|---------------------------------------------------|-------------|\n| **GET**    | /users/`:username_or_email`/reset | [UserController](https://github.com/hexpm/hexpm/blob/main/lib/hexpm_web/controllers/api/user_controller.ex){:target=\"_blank\"} | `:reset` |","ref":"Aura.Users.html#reset_user_password/2-api-details"},{"type":"function","title":"Examples - Aura.Users.reset_user_password/2","doc":"```elixir\niex> alias Aura.Users\niex> opts = [repo_url: \"http://localhost:4000/api\"]\niex> {:ok, user} =  Users.get_current_user(opts)\niex> Users.reset_user_password(user.email, opts)\n:ok\n\n```","ref":"Aura.Users.html#reset_user_password/2-examples"},{"type":"function","title":"Aura.Users.stream_audit_logs/1","doc":"Streams audit logs, scoped to the current authenticated user\n\nNote that the page size is fixed by the API to be 100 per page.\n\n\n\n\n###  Parameters \n  \n| Parameter | Description   |\n|--------|-----------------------|\n| `opts[:repo_url]`   | `t:Aura.Common.repo_url/0` |\n| `opts[:page]`   | `t:Aura.Common.start_page/0` |","ref":"Aura.Users.html#stream_audit_logs/1"},{"type":"function","title":"API Details - Aura.Users.stream_audit_logs/1","doc":"| Method | Path                  | Controller                                        | Action      |\n|--------|-----------------------|---------------------------------------------------|-------------|\n| **GET**    | /users/me/audit-logs | [UserController](https://github.com/hexpm/hexpm/blob/main/lib/hexpm_web/controllers/api/user_controller.ex){:target=\"_blank\"} | `:audit_logs` |","ref":"Aura.Users.html#stream_audit_logs/1-api-details"},{"type":"function","title":"Examples - Aura.Users.stream_audit_logs/1","doc":"```elixir\niex> alias Aura.Users\niex> opts = [repo_url: \"http://localhost:4000/api\"]\niex> audit_logs =  Users.stream_audit_logs(opts)\niex> Enum.empty?(audit_logs)\nfalse\n\n```","ref":"Aura.Users.html#stream_audit_logs/1-examples"},{"type":"type","title":"Aura.Users.user_opts/0","doc":"","ref":"Aura.Users.html#t:user_opts/0"},{"type":"module","title":"Aura.Model.HexAPIKey","doc":"A struct describing an API key record coming from a Hex-compliant API.","ref":"Aura.Model.HexAPIKey.html"},{"type":"module","title":"Examples - Aura.Model.HexAPIKey","doc":"```elixir\n%Aura.Model.HexAPIKey{\n authing_key: false,\n secret: \"3321e19a16017725ced9fe56a0071aa6\",\n inserted_at: ~U[2025-06-02 04:26:33.915977Z],\n name: \"veniam.ut\",\n permissions: [\n   %{domain: \"api\", resource: \"read\"},\n   %{domain: \"api\", resource: \"write\"}\n ],\n revoked_at: nil,\n updated_at: ~U[2025-06-02 04:26:33.915977Z],\n url: \"http://localhost:4000/api/keys/veniam.ut\"\n}\n\n```","ref":"Aura.Model.HexAPIKey.html#module-examples"},{"type":"module","title":"Resources - Aura.Model.HexAPIKey","doc":"* Hex\n    * 📖 [Hex API Specifications](https://github.com/hexpm/specifications){:target=\"_blank\"}\n    * 👾 [Github: hexpm/hex_core](https://github.com/hexpm/hex_core){:target=\"_blank\"}\n    * 👾 [Github: hexpm/hexpm](https://github.com/hexpm/hexpm){:target=\"_blank\"}\n  * Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * ⚗️ [Elixir Form: camatcode](https://elixirforum.com/u/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    * 🦋️ [bsky: @ckcook.studiocms.io](https://bsky.app/profile/ckcook.studiocms.io){:target=\"_blank\"}","ref":"Aura.Model.HexAPIKey.html#module-resources"},{"type":"module","title":"See Also - Aura.Model.HexAPIKey","doc":"* `Aura.APIKeys`","ref":"Aura.Model.HexAPIKey.html#module-see-also"},{"type":"type","title":"Aura.Model.HexAPIKey.api_permission/0","doc":"A permission realm belonging to this API key","ref":"Aura.Model.HexAPIKey.html#t:api_permission/0"},{"type":"type","title":"Keys - Aura.Model.HexAPIKey.api_permission/0","doc":"* **domain** :: `t:Aura.Model.HexAPIKey.domain/0`\n* **resource** :: `t:Aura.Model.HexAPIKey.resource/0`","ref":"Aura.Model.HexAPIKey.html#t:api_permission/0-keys"},{"type":"type","title":"Examples - Aura.Model.HexAPIKey.api_permission/0","doc":"```elixir\n  %{domain: \"api\", resource: \"read\"}\n  %{domain: \"api\", resource: \"write\"}\n\n```","ref":"Aura.Model.HexAPIKey.html#t:api_permission/0-examples"},{"type":"type","title":"See Also - Aura.Model.HexAPIKey.api_permission/0","doc":"* `Aura.APIKeys`","ref":"Aura.Model.HexAPIKey.html#t:api_permission/0-see-also"},{"type":"type","title":"Aura.Model.HexAPIKey.authing_key/0","doc":"Whether this key is the one currently being used to make authenticated requests","ref":"Aura.Model.HexAPIKey.html#t:authing_key/0"},{"type":"type","title":"See Also - Aura.Model.HexAPIKey.authing_key/0","doc":"* `Aura.APIKeys`","ref":"Aura.Model.HexAPIKey.html#t:authing_key/0-see-also"},{"type":"function","title":"Aura.Model.HexAPIKey.build/1","doc":"Builds a `HexAPIKey` from a map\n\n\n\n###  Parameters \n  \n| Parameter | Description   |\n|--------|-----------------------|\n| *m*   | A map to build into a `t:Aura.Model.HexAPIKey.t/0` |","ref":"Aura.Model.HexAPIKey.html#build/1"},{"type":"type","title":"Aura.Model.HexAPIKey.domain/0","doc":"A domain for which this API key is valid","ref":"Aura.Model.HexAPIKey.html#t:domain/0"},{"type":"type","title":"Aura.Model.HexAPIKey.resource/0","doc":"What kind of operations this API key can do within its domain","ref":"Aura.Model.HexAPIKey.html#t:resource/0"},{"type":"type","title":"Aura.Model.HexAPIKey.revoked_date_time/0","doc":"`DateTime` when this key became invalid","ref":"Aura.Model.HexAPIKey.html#t:revoked_date_time/0"},{"type":"type","title":"Examples - Aura.Model.HexAPIKey.revoked_date_time/0","doc":"```elixir\n~U[2025-05-29 18:15:18.244790Z]\n\n```","ref":"Aura.Model.HexAPIKey.html#t:revoked_date_time/0-examples"},{"type":"type","title":"See Also - Aura.Model.HexAPIKey.revoked_date_time/0","doc":"* `Aura.APIKeys`","ref":"Aura.Model.HexAPIKey.html#t:revoked_date_time/0-see-also"},{"type":"type","title":"Aura.Model.HexAPIKey.secret/0","doc":"The API key payload - it is only provided once, upon creation; always `nil` after.\n\n> #### 🔒 Security {: .warning}\n>\n> Guard this secret payload with your life - **never** keep it as plain text in your code.","ref":"Aura.Model.HexAPIKey.html#t:secret/0"},{"type":"type","title":"Examples - Aura.Model.HexAPIKey.secret/0","doc":"```elixir\n\"3321e19a16017725ced9fe56a0071aa6\"\n\n```","ref":"Aura.Model.HexAPIKey.html#t:secret/0-examples"},{"type":"type","title":"See Also - Aura.Model.HexAPIKey.secret/0","doc":"* `Aura.APIKeys`","ref":"Aura.Model.HexAPIKey.html#t:secret/0-see-also"},{"type":"type","title":"Aura.Model.HexAPIKey.t/0","doc":"Type describing an API key coming from a Hex-compliant API.","ref":"Aura.Model.HexAPIKey.html#t:t/0"},{"type":"type","title":"Keys - Aura.Model.HexAPIKey.t/0","doc":"* **name** :: `t:Aura.Common.api_key_name/0`\n* **permissions** :: [`t:Aura.Model.HexAPIKey.api_permission/0`]\n* **url** :: `t:Aura.Model.Common.url/0`\n* **secret** :: `t:Aura.Model.HexAPIKey.secret/0`\n* **inserted_at** :: `t:Aura.Model.Common.inserted_at/0`\n* **updated_at** :: `t:Aura.Model.Common.updated_at/0`\n* **authing_key** :: `t:Aura.Model.HexAPIKey.authing_key/0`\n* **revoked_at** :: `t:Aura.Model.HexAPIKey.revoked_date_time/0`","ref":"Aura.Model.HexAPIKey.html#t:t/0-keys"},{"type":"type","title":"Examples - Aura.Model.HexAPIKey.t/0","doc":"```elixir\n %Aura.Model.HexAPIKey{\n   authing_key: false,\n   secret: \"3321e19a16017725ced9fe56a0071aa6\",\n   inserted_at: ~U[2025-06-02 04:26:33.915977Z],\n   name: \"veniam.ut\",\n   permissions: [\n     %{domain: \"api\", resource: \"read\"},\n     %{domain: \"api\", resource: \"write\"}\n   ],\n   revoked_at: nil,\n   updated_at: ~U[2025-06-02 04:26:33.915977Z],\n   url: \"http://localhost:4000/api/keys/veniam.ut\"\n}\n\n```","ref":"Aura.Model.HexAPIKey.html#t:t/0-examples"},{"type":"type","title":"See Also - Aura.Model.HexAPIKey.t/0","doc":"* `Aura.APIKeys`","ref":"Aura.Model.HexAPIKey.html#t:t/0-see-also"},{"type":"module","title":"Aura.Model.HexAuditLog","doc":"A struct describing a single auditable action from a Hex-compliant API.","ref":"Aura.Model.HexAuditLog.html"},{"type":"module","title":"Examples - Aura.Model.HexAuditLog","doc":"```elixir\n%Aura.Model.HexAuditLog{\n action: \"user.create\",\n params: %{id: 424, handles: nil, username: \"jaqueline1935\"},\n user_agent: \"aura/0.9.0 (Elixir/1.18.3) (OTP/27.3.1) (test)\"\n}\n\n```","ref":"Aura.Model.HexAuditLog.html#module-examples"},{"type":"module","title":"Resources - Aura.Model.HexAuditLog","doc":"* Hex\n    * 📖 [Hex API Specifications](https://github.com/hexpm/specifications){:target=\"_blank\"}\n    * 👾 [Github: hexpm/hex_core](https://github.com/hexpm/hex_core){:target=\"_blank\"}\n    * 👾 [Github: hexpm/hexpm](https://github.com/hexpm/hexpm){:target=\"_blank\"}\n  * Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * ⚗️ [Elixir Form: camatcode](https://elixirforum.com/u/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    * 🦋️ [bsky: @ckcook.studiocms.io](https://bsky.app/profile/ckcook.studiocms.io){:target=\"_blank\"}","ref":"Aura.Model.HexAuditLog.html#module-resources"},{"type":"module","title":"See Also - Aura.Model.HexAuditLog","doc":"* `Aura.Packages`\n  * `Aura.Users`","ref":"Aura.Model.HexAuditLog.html#module-see-also"},{"type":"type","title":"Aura.Model.HexAuditLog.audit_action/0","doc":"A short description of the action taken.","ref":"Aura.Model.HexAuditLog.html#t:audit_action/0"},{"type":"type","title":"Examples - Aura.Model.HexAuditLog.audit_action/0","doc":"```elixir\n\"docs.publish\"\n\"release.publish\"\n\"key.generate\"\n\"email.public\"\n\"email.primary\"\n\"email.add\"\n\"user.create\"\n\n```","ref":"Aura.Model.HexAuditLog.html#t:audit_action/0-examples"},{"type":"type","title":"See Also - Aura.Model.HexAuditLog.audit_action/0","doc":"* `Aura.Packages`\n  * `Aura.Users`","ref":"Aura.Model.HexAuditLog.html#t:audit_action/0-see-also"},{"type":"type","title":"Aura.Model.HexAuditLog.audit_params/0","doc":"A map of all the details of an `t:audit_action/0`","ref":"Aura.Model.HexAuditLog.html#t:audit_params/0"},{"type":"type","title":"Examples - Aura.Model.HexAuditLog.audit_params/0","doc":"```elixir\n%{\n package: %{\n   \"id\" => 445,\n   \"meta\" => %{\n   \"description\" => \"Ea laborum odio eveniet in pariatur doloribus vel ullam aut.\",\n   \"extra\" => nil,\n   \"licenses\" => [\"Apache-2.0\"],\n   \"links\" => %{\"GitHub\" => \"http://marquardt.com\"},\n   \"maintainers\" => nil\n },\n \"name\" => \"zontrax_576460749439376791\"\n },\n release: %{\n   \"has_docs\" => false,\n   \"id\" => 544,\n   \"meta\" => %{\n     \"app\" => \"zontrax_576460749439376791\",\n     \"build_tools\" => [\"mix\"],\n     \"elixir\" => \"~> 1.12\"\n   },\n   \"package_id\" => 445,\n   \"retirement\" => nil,\n   \"version\" => \"0.9.0\"\n }\n}\n\n```","ref":"Aura.Model.HexAuditLog.html#t:audit_params/0-examples"},{"type":"type","title":"See Also - Aura.Model.HexAuditLog.audit_params/0","doc":"* `Aura.Packages`\n  * `Aura.Users`","ref":"Aura.Model.HexAuditLog.html#t:audit_params/0-see-also"},{"type":"function","title":"Aura.Model.HexAuditLog.build/1","doc":"Builds a `HexAuditLog` from a map\n\n\n\n###  Parameters \n  \n| Parameter | Description   |\n|--------|-----------------------|\n| *m*   | A map to build into a `t:Aura.Model.HexAuditLog.t/0` |","ref":"Aura.Model.HexAuditLog.html#build/1"},{"type":"type","title":"Aura.Model.HexAuditLog.t/0","doc":"Type describing an auditable action coming from a Hex-compliant API.","ref":"Aura.Model.HexAuditLog.html#t:t/0"},{"type":"type","title":"Keys - Aura.Model.HexAuditLog.t/0","doc":"* **params** :: `t:Aura.Model.HexAuditLog.audit_params/0`\n* **action** :: `t:Aura.Model.HexAuditLog.audit_action/0`\n* **user_agent** :: `t:Aura.Model.HexAuditLog.user_agent/0`","ref":"Aura.Model.HexAuditLog.html#t:t/0-keys"},{"type":"type","title":"Examples - Aura.Model.HexAuditLog.t/0","doc":"```elixir\n %Aura.Model.HexAuditLog{\n   action: \"user.create\",\n   params: %{id: 424, handles: nil, username: \"jaqueline1935\"},\n   user_agent: \"aura/0.9.0 (Elixir/1.18.3) (OTP/27.3.1) (test)\"\n }\n\n```","ref":"Aura.Model.HexAuditLog.html#t:t/0-examples"},{"type":"type","title":"See Also - Aura.Model.HexAuditLog.t/0","doc":"* `Aura.Packages`\n  * `Aura.Users`","ref":"Aura.Model.HexAuditLog.html#t:t/0-see-also"},{"type":"type","title":"Aura.Model.HexAuditLog.user_agent/0","doc":"The `User-Agent` provided in the HTTP headers relevant to the `t:audit_action/0`","ref":"Aura.Model.HexAuditLog.html#t:user_agent/0"},{"type":"type","title":"Examples - Aura.Model.HexAuditLog.user_agent/0","doc":"```elixir\n\"aura/0.9.0 (Elixir/1.18.3) (OTP/27.3.1) (test)\"\n\n```","ref":"Aura.Model.HexAuditLog.html#t:user_agent/0-examples"},{"type":"type","title":"See Also - Aura.Model.HexAuditLog.user_agent/0","doc":"* `Aura.Packages`\n  * `Aura.Users`","ref":"Aura.Model.HexAuditLog.html#t:user_agent/0-see-also"},{"type":"module","title":"Aura.Model.HexOrg","doc":"Struct defining a Hex organization","ref":"Aura.Model.HexOrg.html"},{"type":"module","title":"Examples - Aura.Model.HexOrg","doc":"```elixir\n%Aura.Model.HexOrg{\n billing_active: false,\n inserted_at: ~U[2025-06-06 21:19:19.530971Z],\n name: \"my_org\",\n updated_at: ~U[2025-06-06 21:19:19.530971Z]\n}\n\n```","ref":"Aura.Model.HexOrg.html#module-examples"},{"type":"module","title":"Resources - Aura.Model.HexOrg","doc":"* Hex\n    * 📖 [Hex API Specifications](https://github.com/hexpm/specifications){:target=\"_blank\"}\n    * 👾 [Github: hexpm/hex_core](https://github.com/hexpm/hex_core){:target=\"_blank\"}\n    * 👾 [Github: hexpm/hexpm](https://github.com/hexpm/hexpm){:target=\"_blank\"}\n  * Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * ⚗️ [Elixir Form: camatcode](https://elixirforum.com/u/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    * 🦋️ [bsky: @ckcook.studiocms.io](https://bsky.app/profile/ckcook.studiocms.io){:target=\"_blank\"}","ref":"Aura.Model.HexOrg.html#module-resources"},{"type":"function","title":"Aura.Model.HexOrg.build/1","doc":"Builds a `HexOrg` from a map\n\n\n\n###  Parameters \n  \n| Parameter | Description   |\n|--------|-----------------------|\n| *m*   | A map to build into a `t:Aura.Model.HexOrg.t/0` |","ref":"Aura.Model.HexOrg.html#build/1"},{"type":"type","title":"Aura.Model.HexOrg.t/0","doc":"Type describing a Hex organization","ref":"Aura.Model.HexOrg.html#t:t/0"},{"type":"type","title":"Keys - Aura.Model.HexOrg.t/0","doc":"* **name** :: `t:Aura.Common.org_name/0`\n* **inserted_at** :: `t:Aura.Model.Common.inserted_at/0`\n* **updated_at** :: `t:Aura.Model.Common.updated_at/0`\n* **billing_active** :: `t:Aura.Model.Common.billing_active/0`","ref":"Aura.Model.HexOrg.html#t:t/0-keys"},{"type":"type","title":"Examples - Aura.Model.HexOrg.t/0","doc":"```elixir\n%Aura.Model.HexOrg{\n billing_active: false,\n inserted_at: ~U[2025-06-06 21:19:19.530971Z],\n name: \"my_org\",\n updated_at: ~U[2025-06-06 21:19:19.530971Z]\n}\n\n```","ref":"Aura.Model.HexOrg.html#t:t/0-examples"},{"type":"type","title":"See Also - Aura.Model.HexOrg.t/0","doc":"* `Aura.Orgs`","ref":"Aura.Model.HexOrg.html#t:t/0-see-also"},{"type":"module","title":"Aura.Model.HexOrgMember","doc":"Struct defining a member of a Hex organization","ref":"Aura.Model.HexOrgMember.html"},{"type":"module","title":"Examples - Aura.Model.HexOrgMember","doc":"```elixir\n%Aura.Model.HexOrgMember{\n email: \"hello@hello.com\",\n role: \"admin\",\n url: \"http://localhost:4000/api/users/hello\",\n username: \"hello\"\n}\n\n```","ref":"Aura.Model.HexOrgMember.html#module-examples"},{"type":"module","title":"Resources - Aura.Model.HexOrgMember","doc":"* Hex\n    * 📖 [Hex API Specifications](https://github.com/hexpm/specifications){:target=\"_blank\"}\n    * 👾 [Github: hexpm/hex_core](https://github.com/hexpm/hex_core){:target=\"_blank\"}\n    * 👾 [Github: hexpm/hexpm](https://github.com/hexpm/hexpm){:target=\"_blank\"}\n  * Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * ⚗️ [Elixir Form: camatcode](https://elixirforum.com/u/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    * 🦋️ [bsky: @ckcook.studiocms.io](https://bsky.app/profile/ckcook.studiocms.io){:target=\"_blank\"}","ref":"Aura.Model.HexOrgMember.html#module-resources"},{"type":"module","title":"See Also - Aura.Model.HexOrgMember","doc":"* `Aura.Orgs`","ref":"Aura.Model.HexOrgMember.html#module-see-also"},{"type":"function","title":"Aura.Model.HexOrgMember.build/1","doc":"Builds a `HexOrgMember` from a map\n\n\n\n###  Parameters \n  \n| Parameter | Description   |\n|--------|-----------------------|\n| *m*   | A map to build into a `t:Aura.Model.HexOrgMember.t/0` |","ref":"Aura.Model.HexOrgMember.html#build/1"},{"type":"type","title":"Aura.Model.HexOrgMember.role/0","doc":"Permission level of the org member","ref":"Aura.Model.HexOrgMember.html#t:role/0"},{"type":"type","title":"Examples - Aura.Model.HexOrgMember.role/0","doc":"```elixir\n:admin\n\n```","ref":"Aura.Model.HexOrgMember.html#t:role/0-examples"},{"type":"type","title":"See Also - Aura.Model.HexOrgMember.role/0","doc":"* `Aura.Orgs`","ref":"Aura.Model.HexOrgMember.html#t:role/0-see-also"},{"type":"type","title":"Aura.Model.HexOrgMember.t/0","doc":"Type describing an org member","ref":"Aura.Model.HexOrgMember.html#t:t/0"},{"type":"type","title":"Keys - Aura.Model.HexOrgMember.t/0","doc":"* **url** :: `t:Aura.Model.Common.url/0`\n* **role** :: `t:Aura.Model.HexOrgMember.role/0`\n* **email** :: `t:Aura.Common.email/0`\n* **username** :: `t:Aura.Common.username/0`","ref":"Aura.Model.HexOrgMember.html#t:t/0-keys"},{"type":"type","title":"Examples - Aura.Model.HexOrgMember.t/0","doc":"```elixir\n%Aura.Model.HexOrgMember{\n email: \"hello@hello.com\",\n role: \"admin\",\n url: \"http://localhost:4000/api/users/hello\",\n username: \"hello\"\n}\n\n```","ref":"Aura.Model.HexOrgMember.html#t:t/0-examples"},{"type":"type","title":"See Also - Aura.Model.HexOrgMember.t/0","doc":"* `Aura.Orgs`","ref":"Aura.Model.HexOrgMember.html#t:t/0-see-also"},{"type":"module","title":"Aura.Model.HexPackage","doc":"A struct describing a package from a Hex-compliant API","ref":"Aura.Model.HexPackage.html"},{"type":"module","title":"Examples - Aura.Model.HexPackage","doc":"```elixir\n%Aura.Model.HexPackage{\n name: \"aura\",\n repository: \"hexpm\",\n private: nil,\n meta: %Aura.Model.HexPackageMeta{\n   maintainers: [],\n   links: %{\n     \"Changelog\" => \"https://github.com/camatcode/aura/blob/master/CHANGELOG.md\",\n     \"GitHub\" => \"https://github.com/camatcode/aura\",\n     \"Website\" => \"https://github.com/camatcode/aura\"\n   },\n   licenses: [\"Apache-2.0\"],\n   description: \"An ergonomic library for investigating the Hex.pm API\"\n },\n downloads: %Aura.Model.HexPackageDownloadStats{all: 4, week: 4, day: 4},\n releases: [\n   %Aura.Model.HexRelease{\n     has_docs: true,\n     inserted_at: ~U[2025-06-01 15:13:00.595681Z],\n     version: \"0.9.0\",\n     url: \"https://hex.pm/api/packages/aura/releases/0.9.0\",\n     downloads: 0\n   }\n ],\n inserted_at: ~U[2025-06-01 15:13:00.589838Z],\n updated_at: ~U[2025-06-01 15:13:04.347899Z],\n url: \"https://hex.pm/api/packages/aura\",\n html_url: \"https://hex.pm/packages/aura\",\n docs_html_url: \"https://hexdocs.pm/aura/\"\n }\n\n```","ref":"Aura.Model.HexPackage.html#module-examples"},{"type":"module","title":"Resources - Aura.Model.HexPackage","doc":"* Hex\n    * 📖 [Hex API Specifications](https://github.com/hexpm/specifications){:target=\"_blank\"}\n    * 👾 [Github: hexpm/hex_core](https://github.com/hexpm/hex_core){:target=\"_blank\"}\n    * 👾 [Github: hexpm/hexpm](https://github.com/hexpm/hexpm){:target=\"_blank\"}\n  * Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * ⚗️ [Elixir Form: camatcode](https://elixirforum.com/u/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    * 🦋️ [bsky: @ckcook.studiocms.io](https://bsky.app/profile/ckcook.studiocms.io){:target=\"_blank\"}","ref":"Aura.Model.HexPackage.html#module-resources"},{"type":"module","title":"See Also - Aura.Model.HexPackage","doc":"* `Aura.Packages`\n  * `Aura.Releases`","ref":"Aura.Model.HexPackage.html#module-see-also"},{"type":"function","title":"Aura.Model.HexPackage.build/1","doc":"Builds a `HexPackage` from a map\n\n\n\n###  Parameters \n  \n| Parameter | Description   |\n|--------|-----------------------|\n| *m*   | A map to build into a `t:Aura.Model.HexPackage.t/0` |","ref":"Aura.Model.HexPackage.html#build/1"},{"type":"type","title":"Aura.Model.HexPackage.private?/0","doc":"Whether this package is publicly available","ref":"Aura.Model.HexPackage.html#t:private?/0"},{"type":"type","title":"Aura.Model.HexPackage.t/0","doc":"Type describing a package from a Hex-compliant API","ref":"Aura.Model.HexPackage.html#t:t/0"},{"type":"type","title":"Keys - Aura.Model.HexPackage.t/0","doc":"* **meta** :: `t:Aura.Model.HexPackageMeta.t/0`\n* **name** :: `t:Aura.Common.package_name/0`\n* **private** :: `t:Aura.Model.HexPackage.private?/0`\n* **url** :: `t:Aura.Model.Common.url/0`\n* **repository** :: `t:Aura.Common.repo_name/0`\n* **releases** :: [`t:Aura.Model.HexRelease.t/0`]\n* **inserted_at** :: `t:Aura.Model.Common.inserted_at/0`\n* **updated_at** :: `t:Aura.Model.Common.updated_at/0`\n* **downloads** :: `t:Aura.Model.HexPackageDownloadStats.t/0`\n* **html_url** :: `t:Aura.Model.Common.html_url/0`\n* **docs_html_url** :: `t:Aura.Model.Common.docs_html_url/0`","ref":"Aura.Model.HexPackage.html#t:t/0-keys"},{"type":"type","title":"Examples - Aura.Model.HexPackage.t/0","doc":"```elixir\n%Aura.Model.HexPackage{\n name: \"aura\",\n repository: \"hexpm\",\n private: nil,\n meta: %Aura.Model.HexPackageMeta{\n   maintainers: [],\n   links: %{\n     \"Changelog\" => \"https://github.com/camatcode/aura/blob/master/CHANGELOG.md\",\n     \"GitHub\" => \"https://github.com/camatcode/aura\",\n     \"Website\" => \"https://github.com/camatcode/aura\"\n   },\n   licenses: [\"Apache-2.0\"],\n   description: \"An ergonomic library for investigating the Hex.pm API\"\n },\n downloads: %Aura.Model.HexPackageDownloadStats{all: 4, week: 4, day: 4},\n releases: [\n   %Aura.Model.HexRelease{\n     has_docs: true,\n     inserted_at: ~U[2025-06-01 15:13:00.595681Z],\n     version: \"0.9.0\",\n     url: \"https://hex.pm/api/packages/aura/releases/0.9.0\",\n     downloads: 0\n   }\n ],\n inserted_at: ~U[2025-06-01 15:13:00.589838Z],\n updated_at: ~U[2025-06-01 15:13:04.347899Z],\n url: \"https://hex.pm/api/packages/aura\",\n html_url: \"https://hex.pm/packages/aura\",\n docs_html_url: \"https://hexdocs.pm/aura/\"\n }\n\n```","ref":"Aura.Model.HexPackage.html#t:t/0-examples"},{"type":"type","title":"See Also - Aura.Model.HexPackage.t/0","doc":"* `Aura.Packages`\n  * `Aura.Releases`","ref":"Aura.Model.HexPackage.html#t:t/0-see-also"},{"type":"module","title":"Aura.Model.HexPackageDownloadStats","doc":"A struct describing download stats associated to a `Aura.Model.HexPackage`","ref":"Aura.Model.HexPackageDownloadStats.html"},{"type":"module","title":"Examples - Aura.Model.HexPackageDownloadStats","doc":"```elixir\n%Aura.Model.HexPackageDownloadStats{all: 196, week: 49, day: 49}\n\n```","ref":"Aura.Model.HexPackageDownloadStats.html#module-examples"},{"type":"module","title":"Resources - Aura.Model.HexPackageDownloadStats","doc":"* Hex\n    * 📖 [Hex API Specifications](https://github.com/hexpm/specifications){:target=\"_blank\"}\n    * 👾 [Github: hexpm/hex_core](https://github.com/hexpm/hex_core){:target=\"_blank\"}\n    * 👾 [Github: hexpm/hexpm](https://github.com/hexpm/hexpm){:target=\"_blank\"}\n  * Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * ⚗️ [Elixir Form: camatcode](https://elixirforum.com/u/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    * 🦋️ [bsky: @ckcook.studiocms.io](https://bsky.app/profile/ckcook.studiocms.io){:target=\"_blank\"}","ref":"Aura.Model.HexPackageDownloadStats.html#module-resources"},{"type":"module","title":"See Also - Aura.Model.HexPackageDownloadStats","doc":"* `Aura.Packages`\n  * `Aura.Releases`","ref":"Aura.Model.HexPackageDownloadStats.html#module-see-also"},{"type":"type","title":"Aura.Model.HexPackageDownloadStats.all_time/0","doc":"Number of downloads since the first release","ref":"Aura.Model.HexPackageDownloadStats.html#t:all_time/0"},{"type":"function","title":"Aura.Model.HexPackageDownloadStats.build/1","doc":"Builds a `HexPackageDownloadStats` from a map\n\n\n\n###  Parameters \n  \n| Parameter | Description   |\n|--------|-----------------------|\n| *m*   | A map to build into a `t:Aura.Model.HexPackageDownloadStats.t/0` |","ref":"Aura.Model.HexPackageDownloadStats.html#build/1"},{"type":"type","title":"Aura.Model.HexPackageDownloadStats.t/0","doc":"Type describing the number of downloads for a `Aura.Model.HexPackage`","ref":"Aura.Model.HexPackageDownloadStats.html#t:t/0"},{"type":"type","title":"Keys - Aura.Model.HexPackageDownloadStats.t/0","doc":"* **all** :: `t:Aura.Model.HexPackageDownloadStats.all_time/0`\n* **day** :: `t:Aura.Model.HexPackageDownloadStats.today/0`\n* **week** :: `t:Aura.Model.HexPackageDownloadStats.this_week/0`","ref":"Aura.Model.HexPackageDownloadStats.html#t:t/0-keys"},{"type":"type","title":"Examples - Aura.Model.HexPackageDownloadStats.t/0","doc":"```elixir\n%Aura.Model.HexPackageDownloadStats{all: 196, week: 49, day: 49}\n\n```","ref":"Aura.Model.HexPackageDownloadStats.html#t:t/0-examples"},{"type":"type","title":"See Also - Aura.Model.HexPackageDownloadStats.t/0","doc":"* `Aura.Packages`\n  * `Aura.Releases`","ref":"Aura.Model.HexPackageDownloadStats.html#t:t/0-see-also"},{"type":"type","title":"Aura.Model.HexPackageDownloadStats.this_week/0","doc":"Number of downloads this week","ref":"Aura.Model.HexPackageDownloadStats.html#t:this_week/0"},{"type":"type","title":"Aura.Model.HexPackageDownloadStats.today/0","doc":"Number of downloads today","ref":"Aura.Model.HexPackageDownloadStats.html#t:today/0"},{"type":"module","title":"Aura.Model.HexPackageMeta","doc":"A struct describing additional metadata about a `Aura.Model.HexPackage`","ref":"Aura.Model.HexPackageMeta.html"},{"type":"module","title":"Examples - Aura.Model.HexPackageMeta","doc":"```elixir\n%Aura.Model.HexPackageMeta{\n maintainers: [],\n links: %{\"GitHub\" => \"https://github.com/michalmuskala/jason\"},\n licenses: [\"Apache-2.0\"],\n description: \"A blazing fast JSON parser and generator in pure Elixir.\"\n}\n\n```","ref":"Aura.Model.HexPackageMeta.html#module-examples"},{"type":"module","title":"Resources - Aura.Model.HexPackageMeta","doc":"* Hex\n    * 📖 [Hex API Specifications](https://github.com/hexpm/specifications){:target=\"_blank\"}\n    * 👾 [Github: hexpm/hex_core](https://github.com/hexpm/hex_core){:target=\"_blank\"}\n    * 👾 [Github: hexpm/hexpm](https://github.com/hexpm/hexpm){:target=\"_blank\"}\n  * Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * ⚗️ [Elixir Form: camatcode](https://elixirforum.com/u/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    * 🦋️ [bsky: @ckcook.studiocms.io](https://bsky.app/profile/ckcook.studiocms.io){:target=\"_blank\"}","ref":"Aura.Model.HexPackageMeta.html#module-resources"},{"type":"module","title":"See Also - Aura.Model.HexPackageMeta","doc":"* `Aura.Packages`\n  * `Aura.Releases`","ref":"Aura.Model.HexPackageMeta.html#module-see-also"},{"type":"type","title":"Aura.Model.HexPackageMeta.additional_links/0","doc":"Additional URLs associated with the Hex package","ref":"Aura.Model.HexPackageMeta.html#t:additional_links/0"},{"type":"type","title":"Examples - Aura.Model.HexPackageMeta.additional_links/0","doc":"```elixir\n%{\"GitHub\" => \"https://github.com/michalmuskala/jason\"}\n\n```","ref":"Aura.Model.HexPackageMeta.html#t:additional_links/0-examples"},{"type":"type","title":"See Also - Aura.Model.HexPackageMeta.additional_links/0","doc":"* `Aura.Packages`\n  * `Aura.Releases`","ref":"Aura.Model.HexPackageMeta.html#t:additional_links/0-see-also"},{"type":"function","title":"Aura.Model.HexPackageMeta.build/1","doc":"Builds a `HexPackageMeta` from a map\n\n\n\n###  Parameters \n  \n| Parameter | Description   |\n|--------|-----------------------|\n| *m*   | A map to build into a `t:Aura.Model.HexPackageMeta.t/0` |","ref":"Aura.Model.HexPackageMeta.html#build/1"},{"type":"type","title":"Aura.Model.HexPackageMeta.meta_url/0","doc":"Additional external URL relating to the package","ref":"Aura.Model.HexPackageMeta.html#t:meta_url/0"},{"type":"type","title":"Examples - Aura.Model.HexPackageMeta.meta_url/0","doc":"```elixir\n\"https://github.com/michalmuskala/jason\"\n\n```","ref":"Aura.Model.HexPackageMeta.html#t:meta_url/0-examples"},{"type":"type","title":"See Also - Aura.Model.HexPackageMeta.meta_url/0","doc":"* `Aura.Packages`\n  * `Aura.Releases`","ref":"Aura.Model.HexPackageMeta.html#t:meta_url/0-see-also"},{"type":"type","title":"Aura.Model.HexPackageMeta.package_description/0","doc":"Short, human-readable description of the package","ref":"Aura.Model.HexPackageMeta.html#t:package_description/0"},{"type":"type","title":"Examples - Aura.Model.HexPackageMeta.package_description/0","doc":"```elixir\n\"A blazing fast JSON parser and generator in pure Elixir.\"\n\n```","ref":"Aura.Model.HexPackageMeta.html#t:package_description/0-examples"},{"type":"type","title":"See Also - Aura.Model.HexPackageMeta.package_description/0","doc":"* `Aura.Packages`\n  * `Aura.Releases`","ref":"Aura.Model.HexPackageMeta.html#t:package_description/0-see-also"},{"type":"type","title":"Aura.Model.HexPackageMeta.software_license/0","doc":"The software license associated to the package","ref":"Aura.Model.HexPackageMeta.html#t:software_license/0"},{"type":"type","title":"Examples - Aura.Model.HexPackageMeta.software_license/0","doc":"```elixir\n\"Apache-2.0\"\n\n```","ref":"Aura.Model.HexPackageMeta.html#t:software_license/0-examples"},{"type":"type","title":"See Also - Aura.Model.HexPackageMeta.software_license/0","doc":"* `Aura.Packages`\n  * `Aura.Releases`","ref":"Aura.Model.HexPackageMeta.html#t:software_license/0-see-also"},{"type":"type","title":"Aura.Model.HexPackageMeta.t/0","doc":"Type describing additional metadata about a `Aura.Model.HexPackage`","ref":"Aura.Model.HexPackageMeta.html#t:t/0"},{"type":"type","title":"Keys - Aura.Model.HexPackageMeta.t/0","doc":"* **links** :: `t:Aura.Model.HexPackageMeta.additional_links/0`\n* **description** :: `t:Aura.Model.HexPackageMeta.package_description/0`\n* **maintainers** :: [`t:Aura.Common.username/0`]\n* **licenses** :: [`t:Aura.Model.HexPackageMeta.software_license/0`]","ref":"Aura.Model.HexPackageMeta.html#t:t/0-keys"},{"type":"type","title":"Examples - Aura.Model.HexPackageMeta.t/0","doc":"```elixir\n%Aura.Model.HexPackageMeta{\n maintainers: [],\n links: %{\"GitHub\" => \"https://github.com/michalmuskala/jason\"},\n licenses: [\"Apache-2.0\"],\n description: \"A blazing fast JSON parser and generator in pure Elixir.\"\n}\n\n```","ref":"Aura.Model.HexPackageMeta.html#t:t/0-examples"},{"type":"type","title":"See Also - Aura.Model.HexPackageMeta.t/0","doc":"* `Aura.Packages`\n  * `Aura.Releases`","ref":"Aura.Model.HexPackageMeta.html#t:t/0-see-also"},{"type":"module","title":"Aura.Model.HexPackageOwner","doc":"A struct describing an owner of a `Aura.Model.HexPackage`","ref":"Aura.Model.HexPackageOwner.html"},{"type":"module","title":"Examples - Aura.Model.HexPackageOwner","doc":"```elixir\n%Aura.Model.HexPackageOwner{\n email: \"cam.cook.codes@gmail.com\",\n full_name: \"Cam Cook\",\n handles: %{\n   elixir_forum: \"https://elixirforum.com/u/camatcode\",\n   git_hub: \"https://github.com/camatcode\"\n },\n inserted_at: ~U[2025-05-01 19:45:03.289458Z],\n level: :full,\n updated_at: ~U[2025-06-01 15:40:38.852881Z],\n url: \"https://hex.pm/api/users/camatcode\",\n username: \"camatcode\"\n}\n\n```","ref":"Aura.Model.HexPackageOwner.html#module-examples"},{"type":"module","title":"Resources - Aura.Model.HexPackageOwner","doc":"* Hex\n    * 📖 [Hex API Specifications](https://github.com/hexpm/specifications){:target=\"_blank\"}\n    * 👾 [Github: hexpm/hex_core](https://github.com/hexpm/hex_core){:target=\"_blank\"}\n    * 👾 [Github: hexpm/hexpm](https://github.com/hexpm/hexpm){:target=\"_blank\"}\n  * Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * ⚗️ [Elixir Form: camatcode](https://elixirforum.com/u/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    * 🦋️ [bsky: @ckcook.studiocms.io](https://bsky.app/profile/ckcook.studiocms.io){:target=\"_blank\"}","ref":"Aura.Model.HexPackageOwner.html#module-resources"},{"type":"module","title":"See Also - Aura.Model.HexPackageOwner","doc":"* `Aura.Packages`\n  * `Aura.Releases`","ref":"Aura.Model.HexPackageOwner.html#module-see-also"},{"type":"function","title":"Aura.Model.HexPackageOwner.build/1","doc":"Builds a `HexPackageOwner` from a map\n\n\n\n###  Parameters \n  \n| Parameter | Description   |\n|--------|-----------------------|\n| *m*   | A map to build into a `t:Aura.Model.HexPackageOwner.t/0` |","ref":"Aura.Model.HexPackageOwner.html#build/1"},{"type":"type","title":"Aura.Model.HexPackageOwner.full_name/0","doc":"The user's full name","ref":"Aura.Model.HexPackageOwner.html#t:full_name/0"},{"type":"type","title":"Examples - Aura.Model.HexPackageOwner.full_name/0","doc":"```elixir\n\"Jane Smith\"\n\n```","ref":"Aura.Model.HexPackageOwner.html#t:full_name/0-examples"},{"type":"type","title":"See Also - Aura.Model.HexPackageOwner.full_name/0","doc":"* `Aura.Packages`\n  * `Aura.Releases`","ref":"Aura.Model.HexPackageOwner.html#t:full_name/0-see-also"},{"type":"type","title":"Aura.Model.HexPackageOwner.level/0","doc":"The user's administration level for this package","ref":"Aura.Model.HexPackageOwner.html#t:level/0"},{"type":"type","title":"See Also - Aura.Model.HexPackageOwner.level/0","doc":"* `Aura.Packages`\n  * `Aura.Releases`","ref":"Aura.Model.HexPackageOwner.html#t:level/0-see-also"},{"type":"type","title":"Aura.Model.HexPackageOwner.social_handles/0","doc":"A map of social media handles owned by this user","ref":"Aura.Model.HexPackageOwner.html#t:social_handles/0"},{"type":"type","title":"Examples - Aura.Model.HexPackageOwner.social_handles/0","doc":"```elixir\n%{\n   git_hub: \"https://github.com/michalmuskala\",\n   twitter: \"https://twitter.com/michalmuskala\",\n   slack: \"https://elixir-slackin.herokuapp.com/\",\n   libera: \"irc://irc.libera.chat/elixir\",\n   elixir_forum: \"https://elixirforum.com/u/michalmuskala\"\n}\n\n```","ref":"Aura.Model.HexPackageOwner.html#t:social_handles/0-examples"},{"type":"type","title":"See Also - Aura.Model.HexPackageOwner.social_handles/0","doc":"* `Aura.Packages`\n  * `Aura.Releases`","ref":"Aura.Model.HexPackageOwner.html#t:social_handles/0-see-also"},{"type":"type","title":"Aura.Model.HexPackageOwner.t/0","doc":"Type describing an owner of a `Aura.Model.HexPackage`","ref":"Aura.Model.HexPackageOwner.html#t:t/0"},{"type":"type","title":"Keys - Aura.Model.HexPackageOwner.t/0","doc":"* **level** :: `t:Aura.Model.HexPackageOwner.level/0`\n* **handles** :: `t:Aura.Model.HexPackageOwner.social_handles/0`\n* **url** :: `t:Aura.Model.Common.url/0`\n* **email** :: `t:Aura.Common.email/0`\n* **username** :: `t:Aura.Common.username/0`\n* **inserted_at** :: `t:Aura.Model.Common.inserted_at/0`\n* **updated_at** :: `t:Aura.Model.Common.updated_at/0`\n* **full_name** :: `t:Aura.Model.HexPackageOwner.full_name/0`","ref":"Aura.Model.HexPackageOwner.html#t:t/0-keys"},{"type":"type","title":"Examples - Aura.Model.HexPackageOwner.t/0","doc":"```elixir\n%Aura.Model.HexPackageOwner{\n email: \"cam.cook.codes@gmail.com\",\n full_name: \"Cam Cook\",\n handles: %{\n   elixir_forum: \"https://elixirforum.com/u/camatcode\",\n   git_hub: \"https://github.com/camatcode\"\n },\n inserted_at: ~U[2025-05-01 19:45:03.289458Z],\n level: :full,\n updated_at: ~U[2025-06-01 15:40:38.852881Z],\n url: \"https://hex.pm/api/users/camatcode\",\n username: \"camatcode\"\n}\n\n```","ref":"Aura.Model.HexPackageOwner.html#t:t/0-examples"},{"type":"type","title":"See Also - Aura.Model.HexPackageOwner.t/0","doc":"* `Aura.Packages`\n  * `Aura.Releases`","ref":"Aura.Model.HexPackageOwner.html#t:t/0-see-also"},{"type":"module","title":"Aura.Model.HexRelease","doc":"A struct describing a single release of a `Aura.Model.HexPackage`","ref":"Aura.Model.HexRelease.html"},{"type":"module","title":"Examples - Aura.Model.HexRelease","doc":"```elixir\n%Aura.Model.HexRelease{\n checksum: \"4eaafe67a4b2d3a3b7f4637106ce81707cfa0977e6b3b44450cde4c4626a3c1a\",\n configs: %{\n   \"erlang.mk\" => \"dep_aura = hex 0.9.0\",\n   \"mix.exs\" => \"{:aura, \"~> 0.9.0\"}\",\n   \"rebar.config\" => \"{aura, \"0.9.0\"}\"\n },\n docs_html_url: \"https://hexdocs.pm/aura/0.9.0/\",\n has_docs: true,\n html_url: \"https://hex.pm/packages/aura/0.9.0\",\n inserted_at: ~U[2025-06-01 15:13:00.595681Z],\n meta: %{elixir: \"~> 1.18\", app: \"aura\", build_tools: [\"mix\"]},\n package_url: \"https://hex.pm/api/packages/aura\",\n publisher: %{\n   url: \"https://hex.pm/api/users/camatcode\",\n   username: \"camatcode\",\n   email: \"cam.cook.codes@gmail.com\"\n },\n requirements: [\n   %{optional: false, app: \"cachex\", requirement: \"~> 4.0\"},\n   %{optional: false, app: \"date_time_parser\", requirement: \"~> 1.2.0\"},\n   %{optional: false, app: \"proper_case\", requirement: \"~> 1.3\"},\n   %{optional: false, app: \"req\", requirement: \"~> 0.5.10\"}\n ],\n retirement: nil,\n updated_at: ~U[2025-06-01 15:13:04.347130Z],\n version: \"0.9.0\",\n url: \"https://hex.pm/api/packages/aura/releases/0.9.0\",\n downloads: 15\n}\n\n```","ref":"Aura.Model.HexRelease.html#module-examples"},{"type":"module","title":"Resources - Aura.Model.HexRelease","doc":"* Hex\n    * 📖 [Hex API Specifications](https://github.com/hexpm/specifications){:target=\"_blank\"}\n    * 👾 [Github: hexpm/hex_core](https://github.com/hexpm/hex_core){:target=\"_blank\"}\n    * 👾 [Github: hexpm/hexpm](https://github.com/hexpm/hexpm){:target=\"_blank\"}\n  * Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * ⚗️ [Elixir Form: camatcode](https://elixirforum.com/u/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    * 🦋️ [bsky: @ckcook.studiocms.io](https://bsky.app/profile/ckcook.studiocms.io){:target=\"_blank\"}","ref":"Aura.Model.HexRelease.html#module-resources"},{"type":"module","title":"See Also - Aura.Model.HexRelease","doc":"* `Aura.Packages`","ref":"Aura.Model.HexRelease.html#module-see-also"},{"type":"function","title":"Aura.Model.HexRelease.build/1","doc":"Builds a `HexRelease` from a map\n\n\n\n###  Parameters \n  \n| Parameter | Description   |\n|--------|-----------------------|\n| *m*   | A map to build into a `t:Aura.Model.HexRelease.t/0` |","ref":"Aura.Model.HexRelease.html#build/1"},{"type":"type","title":"Aura.Model.HexRelease.build_tool_declarations/0","doc":"A mapping between a build-tool config and the configuration needed to grab this release","ref":"Aura.Model.HexRelease.html#t:build_tool_declarations/0"},{"type":"type","title":"Examples - Aura.Model.HexRelease.build_tool_declarations/0","doc":"```elixir\n   %{\n     \"erlang.mk\" => \"dep_aura = hex 0.9.0\",\n     \"mix.exs\" => \"{:aura, \"~> 0.9.0\"}\",\n     \"rebar.config\" => \"{aura, \"0.9.0\"}\"\n   }\n\n```","ref":"Aura.Model.HexRelease.html#t:build_tool_declarations/0-examples"},{"type":"type","title":"See Also - Aura.Model.HexRelease.build_tool_declarations/0","doc":"* `Aura.Releases`","ref":"Aura.Model.HexRelease.html#t:build_tool_declarations/0-see-also"},{"type":"type","title":"Aura.Model.HexRelease.docs?/0","doc":"Whether this release has associated docs","ref":"Aura.Model.HexRelease.html#t:docs?/0"},{"type":"type","title":"Aura.Model.HexRelease.package_reference_url/0","doc":"URI reference to the `Aura.Model.HexPackage` this release belongs to","ref":"Aura.Model.HexRelease.html#t:package_reference_url/0"},{"type":"type","title":"Examples - Aura.Model.HexRelease.package_reference_url/0","doc":"```elixir\n\"https://hex.pm/api/packages/aura/releases/0.9.0\"\n\n```","ref":"Aura.Model.HexRelease.html#t:package_reference_url/0-examples"},{"type":"type","title":"See Also - Aura.Model.HexRelease.package_reference_url/0","doc":"* `Aura.Releases`","ref":"Aura.Model.HexRelease.html#t:package_reference_url/0-see-also"},{"type":"type","title":"Aura.Model.HexRelease.release_checksum/0","doc":"SHA-256 checksum of the associated release **tar.gz**","ref":"Aura.Model.HexRelease.html#t:release_checksum/0"},{"type":"type","title":"Examples - Aura.Model.HexRelease.release_checksum/0","doc":"```elixir\n  \"4eaafe67a4b2d3a3b7f4637106ce81707cfa0977e6b3b44450cde4c4626a3c1a\"\n\n```","ref":"Aura.Model.HexRelease.html#t:release_checksum/0-examples"},{"type":"type","title":"See Also - Aura.Model.HexRelease.release_checksum/0","doc":"* `Aura.Releases`","ref":"Aura.Model.HexRelease.html#t:release_checksum/0-see-also"},{"type":"type","title":"Aura.Model.HexRelease.release_downloads/0","doc":"Number of all time downloads of this release","ref":"Aura.Model.HexRelease.html#t:release_downloads/0"},{"type":"type","title":"Aura.Model.HexRelease.release_meta/0","doc":"Additional information relevant to the release","ref":"Aura.Model.HexRelease.html#t:release_meta/0"},{"type":"type","title":"Examples - Aura.Model.HexRelease.release_meta/0","doc":"```elixir\n%{elixir: \"~> 1.18\", app: \"aura\", build_tools: [\"mix\"]}\n\n```","ref":"Aura.Model.HexRelease.html#t:release_meta/0-examples"},{"type":"type","title":"See Also - Aura.Model.HexRelease.release_meta/0","doc":"* `Aura.Releases`","ref":"Aura.Model.HexRelease.html#t:release_meta/0-see-also"},{"type":"type","title":"Aura.Model.HexRelease.release_publisher/0","doc":"Information about the user which published this release","ref":"Aura.Model.HexRelease.html#t:release_publisher/0"},{"type":"type","title":"Examples - Aura.Model.HexRelease.release_publisher/0","doc":"```elixir\n%{\n url: \"https://hex.pm/api/users/camatcode\",\n username: \"camatcode\",\n email: \"cam.cook.codes@gmail.com\"\n}\n\n```","ref":"Aura.Model.HexRelease.html#t:release_publisher/0-examples"},{"type":"type","title":"See Also - Aura.Model.HexRelease.release_publisher/0","doc":"* `Aura.Releases`","ref":"Aura.Model.HexRelease.html#t:release_publisher/0-see-also"},{"type":"type","title":"Aura.Model.HexRelease.release_requirement/0","doc":"A dependency of this release","ref":"Aura.Model.HexRelease.html#t:release_requirement/0"},{"type":"type","title":"Examples - Aura.Model.HexRelease.release_requirement/0","doc":"```elixir\n%{optional: false, app: \"req\", requirement: \"~> 0.5.10\"}\n\n```","ref":"Aura.Model.HexRelease.html#t:release_requirement/0-examples"},{"type":"type","title":"See Also - Aura.Model.HexRelease.release_requirement/0","doc":"* `Aura.Releases`","ref":"Aura.Model.HexRelease.html#t:release_requirement/0-see-also"},{"type":"type","title":"Aura.Model.HexRelease.retired?/0","doc":"Whether this release is considered retired","ref":"Aura.Model.HexRelease.html#t:retired?/0"},{"type":"type","title":"Aura.Model.HexRelease.t/0","doc":"Type describing a `Aura.Model.HexRelease`","ref":"Aura.Model.HexRelease.html#t:t/0"},{"type":"type","title":"Keys - Aura.Model.HexRelease.t/0","doc":"* **meta** :: `t:Aura.Model.HexRelease.release_meta/0`\n* **version** :: `t:Aura.Common.release_version/0`\n* **checksum** :: `t:Aura.Model.HexRelease.release_checksum/0`\n* **url** :: `t:Aura.Model.Common.url/0`\n* **requirements** :: [`t:Aura.Model.HexRelease.release_requirement/0`]\n* **inserted_at** :: `t:Aura.Model.Common.inserted_at/0`\n* **updated_at** :: `t:Aura.Model.Common.updated_at/0`\n* **downloads** :: `t:Aura.Model.HexRelease.release_downloads/0`\n* **html_url** :: `t:Aura.Model.Common.html_url/0`\n* **docs_html_url** :: `t:Aura.Model.Common.docs_html_url/0`\n* **configs** :: `t:Aura.Model.HexRelease.build_tool_declarations/0`\n* **has_docs** :: `t:Aura.Model.HexRelease.docs?/0`\n* **publisher** :: `t:Aura.Model.HexRelease.release_publisher/0`\n* **retirement** :: `t:Aura.Model.HexRelease.retired?/0`\n* **package_url** :: `t:Aura.Model.HexRelease.package_reference_url/0`","ref":"Aura.Model.HexRelease.html#t:t/0-keys"},{"type":"type","title":"Examples - Aura.Model.HexRelease.t/0","doc":"```elixir\n%Aura.Model.HexRelease{\n checksum: \"4eaafe67a4b2d3a3b7f4637106ce81707cfa0977e6b3b44450cde4c4626a3c1a\",\n configs: %{\n   \"erlang.mk\" => \"dep_aura = hex 0.9.0\",\n   \"mix.exs\" => \"{:aura, \"~> 0.9.0\"}\",\n   \"rebar.config\" => \"{aura, \"0.9.0\"}\"\n },\n docs_html_url: \"https://hexdocs.pm/aura/0.9.0/\",\n has_docs: true,\n html_url: \"https://hex.pm/packages/aura/0.9.0\",\n inserted_at: ~U[2025-06-01 15:13:00.595681Z],\n meta: %{elixir: \"~> 1.18\", app: \"aura\", build_tools: [\"mix\"]},\n package_url: \"https://hex.pm/api/packages/aura\",\n publisher: %{\n   url: \"https://hex.pm/api/users/camatcode\",\n   username: \"camatcode\",\n   email: \"cam.cook.codes@gmail.com\"\n },\n requirements: [\n   %{optional: false, app: \"cachex\", requirement: \"~> 4.0\"},\n   %{optional: false, app: \"date_time_parser\", requirement: \"~> 1.2.0\"},\n   %{optional: false, app: \"proper_case\", requirement: \"~> 1.3\"},\n   %{optional: false, app: \"req\", requirement: \"~> 0.5.10\"}\n ],\n retirement: nil,\n updated_at: ~U[2025-06-01 15:13:04.347130Z],\n version: \"0.9.0\",\n url: \"https://hex.pm/api/packages/aura/releases/0.9.0\",\n downloads: 15\n }\n\n```","ref":"Aura.Model.HexRelease.html#t:t/0-examples"},{"type":"type","title":"See Also - Aura.Model.HexRelease.t/0","doc":"* `Aura.Releases`","ref":"Aura.Model.HexRelease.html#t:t/0-see-also"},{"type":"module","title":"Aura.Model.HexRepo","doc":"A struct describing a repository from a Hex-compliant API.\n\nThe main Hex.pm public repo is named `\"hexpm\"`; though private repos do exist.","ref":"Aura.Model.HexRepo.html"},{"type":"module","title":"Examples - Aura.Model.HexRepo","doc":"```elixir\n%Aura.Model.HexRepo{\n name: \"hexpm\",\n public: nil,\n active: nil,\n billing_active: nil,\n inserted_at: ~U[2025-05-29 18:15:18.185511Z],\n updated_at: ~U[2025-05-29 18:15:18.185511Z]\n}\n\n```","ref":"Aura.Model.HexRepo.html#module-examples"},{"type":"module","title":"Resources - Aura.Model.HexRepo","doc":"* Hex\n    * 📖 [Hex API Specifications](https://github.com/hexpm/specifications){:target=\"_blank\"}\n    * 👾 [Github: hexpm/hex_core](https://github.com/hexpm/hex_core){:target=\"_blank\"}\n    * 👾 [Github: hexpm/hexpm](https://github.com/hexpm/hexpm){:target=\"_blank\"}\n  * Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * ⚗️ [Elixir Form: camatcode](https://elixirforum.com/u/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    * 🦋️ [bsky: @ckcook.studiocms.io](https://bsky.app/profile/ckcook.studiocms.io){:target=\"_blank\"}","ref":"Aura.Model.HexRepo.html#module-resources"},{"type":"module","title":"See Also - Aura.Model.HexRepo","doc":"* `Aura.Repos`","ref":"Aura.Model.HexRepo.html#module-see-also"},{"type":"type","title":"Aura.Model.HexRepo.active/0","doc":"Whether the repository is active","ref":"Aura.Model.HexRepo.html#t:active/0"},{"type":"function","title":"Aura.Model.HexRepo.build/1","doc":"Builds a `HexRepo` from a map\n\n\n\n###  Parameters \n  \n| Parameter | Description   |\n|--------|-----------------------|\n| *m*   | A map to build into a `t:Aura.Model.HexRepo.t/0` |","ref":"Aura.Model.HexRepo.html#build/1"},{"type":"type","title":"Aura.Model.HexRepo.public/0","doc":"Whether the repository is public","ref":"Aura.Model.HexRepo.html#t:public/0"},{"type":"type","title":"Aura.Model.HexRepo.t/0","doc":"Type describing a repository from a Hex-compliant API.","ref":"Aura.Model.HexRepo.html#t:t/0"},{"type":"type","title":"Keys - Aura.Model.HexRepo.t/0","doc":"* **active** :: `t:Aura.Model.HexRepo.active/0`\n* **public** :: `t:Aura.Model.HexRepo.public/0`\n* **inserted_at** :: `t:Aura.Model.Common.inserted_at/0`\n* **updated_at** :: `t:Aura.Model.Common.updated_at/0`\n* **billing_active** :: `t:Aura.Model.Common.billing_active/0`","ref":"Aura.Model.HexRepo.html#t:t/0-keys"},{"type":"type","title":"Examples - Aura.Model.HexRepo.t/0","doc":"```elixir\n%Aura.Model.HexRepo{\n name: \"hexpm\",\n public: nil,\n active: nil,\n billing_active: nil,\n inserted_at: ~U[2025-05-29 18:15:18.185511Z],\n updated_at: ~U[2025-05-29 18:15:18.185511Z]\n}\n\n```","ref":"Aura.Model.HexRepo.html#t:t/0-examples"},{"type":"module","title":"Aura.Model.HexUser","doc":"A struct defining a User for a Hex-compliant API","ref":"Aura.Model.HexUser.html"},{"type":"module","title":"Examples - Aura.Model.HexUser","doc":"```elixir\n%Aura.Model.HexUser{\n  username: \"alta2001\",\n  email: \"morgan.gulgowski@stehr.biz\",\n  inserted_at: ~U[2025-06-04 00:53:31.880685Z],\n  updated_at: ~U[2025-06-04 00:53:31.880685Z],\n  url: \"http://localhost:4000/api/users/alta2001\"\n}\n\n```","ref":"Aura.Model.HexUser.html#module-examples"},{"type":"module","title":"Resources - Aura.Model.HexUser","doc":"* Hex\n    * 📖 [Hex API Specifications](https://github.com/hexpm/specifications){:target=\"_blank\"}\n    * 👾 [Github: hexpm/hex_core](https://github.com/hexpm/hex_core){:target=\"_blank\"}\n    * 👾 [Github: hexpm/hexpm](https://github.com/hexpm/hexpm){:target=\"_blank\"}\n  * Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * ⚗️ [Elixir Form: camatcode](https://elixirforum.com/u/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    * 🦋️ [bsky: @ckcook.studiocms.io](https://bsky.app/profile/ckcook.studiocms.io){:target=\"_blank\"}","ref":"Aura.Model.HexUser.html#module-resources"},{"type":"module","title":"See Also - Aura.Model.HexUser","doc":"* `Aura.Users`","ref":"Aura.Model.HexUser.html#module-see-also"},{"type":"function","title":"Aura.Model.HexUser.build/1","doc":"Builds a `HexUser` from a map\n\n\n\n###  Parameters \n  \n| Parameter | Description   |\n|--------|-----------------------|\n| *m*   | A map to build into a `t:Aura.Model.HexUser.t/0` |","ref":"Aura.Model.HexUser.html#build/1"},{"type":"type","title":"Aura.Model.HexUser.t/0","doc":"Type defining a User for a Hex-compliant API","ref":"Aura.Model.HexUser.html#t:t/0"},{"type":"type","title":"Keys - Aura.Model.HexUser.t/0","doc":"* **url** :: `t:Aura.Model.Common.url/0`\n* **email** :: `t:Aura.Common.email/0`\n* **username** :: `t:Aura.Common.username/0`\n* **inserted_at** :: `t:Aura.Model.Common.inserted_at/0`\n* **updated_at** :: `t:Aura.Model.Common.updated_at/0`","ref":"Aura.Model.HexUser.html#t:t/0-keys"},{"type":"type","title":"Examples - Aura.Model.HexUser.t/0","doc":"```elixir\n%Aura.Model.HexUser{\n username: \"alta2001\",\n email: \"morgan.gulgowski@stehr.biz\",\n inserted_at: ~U[2025-06-04 00:53:31.880685Z],\n updated_at: ~U[2025-06-04 00:53:31.880685Z],\n url: \"http://localhost:4000/api/users/alta2001\"\n}\n\n```","ref":"Aura.Model.HexUser.html#t:t/0-examples"},{"type":"module","title":"Aura.Common","doc":"Common capabilities across all Aura services","ref":"Aura.Common.html"},{"type":"module","title":"Resources - Aura.Common","doc":"* Hex\n    * 📖 [Hex API Specifications](https://github.com/hexpm/specifications){:target=\"_blank\"}\n    * 👾 [Github: hexpm/hex_core](https://github.com/hexpm/hex_core){:target=\"_blank\"}\n    * 👾 [Github: hexpm/hexpm](https://github.com/hexpm/hexpm){:target=\"_blank\"}\n  * Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * ⚗️ [Elixir Form: camatcode](https://elixirforum.com/u/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    * 🦋️ [bsky: @ckcook.studiocms.io](https://bsky.app/profile/ckcook.studiocms.io){:target=\"_blank\"}","ref":"Aura.Common.html#module-resources"},{"type":"type","title":"Aura.Common.api_key_name/0","doc":"A human-readable name for this API key","ref":"Aura.Common.html#t:api_key_name/0"},{"type":"type","title":"Examples - Aura.Common.api_key_name/0","doc":"```elixir\n \"my_computer\"\n\n```","ref":"Aura.Common.html#t:api_key_name/0-examples"},{"type":"type","title":"Aura.Common.api_path/0","doc":"The path parameter of the request","ref":"Aura.Common.html#t:api_path/0"},{"type":"type","title":"Aura.Common.audit_opts/0","doc":"Options to modify an audit request","ref":"Aura.Common.html#t:audit_opts/0"},{"type":"type","title":"Keys - Aura.Common.audit_opts/0","doc":"* **repo_url** :: `t:Aura.Common.repo_url/0`\n* **page** :: `t:Aura.Common.start_page/0`","ref":"Aura.Common.html#t:audit_opts/0-keys"},{"type":"function","title":"Aura.Common.determine_path/2","doc":"Determines a `t:api_path/0` by investigating **opts** for a `:repo` or `:org` key, representing a `Aura.Model.HexRepo` or a `Aura.Model.HexOrganization`.\n\nIf present, **path** will be modified to scope solely to that repo or org, otherwise the **path** is unmodified.\n\n\n\n\n###  Parameters \n  \n| Parameter | Description   |\n|--------|-----------------------|\n| *path*   | `t:api_path/0` |\n| *opts*   | option parameters used to modify requests |","ref":"Aura.Common.html#determine_path/2"},{"type":"function","title":"Examples - Aura.Common.determine_path/2","doc":"```elixir\niex> alias Aura.Common\niex> alias Aura.Model.HexPackage\niex> opts = [repo_url: \"http://localhost:4000/api\", repo: \"hexpm\", page: 2, sort: :total_downloads]\niex> {_path, _opts} = Common.determine_path(opts, \"/packages\")\n{\"/repos/hexpm/packages\", [repo_url: \"http://localhost:4000/api\", page: 2, sort: :total_downloads]}\niex> opts = [repo_url: \"http://localhost:4000/api\", org: \"my_org\", page: 2]\niex> {_path, _opts} = Common.determine_path(opts, \"/keys\")\n{\"/orgs/my_org/keys\", [repo_url: \"http://localhost:4000/api\", page: 2]}\n\n```","ref":"Aura.Common.html#determine_path/2-examples"},{"type":"type","title":"Aura.Common.email/0","doc":"An email address associated with this record","ref":"Aura.Common.html#t:email/0"},{"type":"type","title":"Examples - Aura.Common.email/0","doc":"```elixir\n\"hello@example.com\"\n\n```","ref":"Aura.Common.html#t:email/0-examples"},{"type":"type","title":"Aura.Common.org_name/0","doc":"Name of the Hex organization","ref":"Aura.Common.html#t:org_name/0"},{"type":"type","title":"Examples - Aura.Common.org_name/0","doc":"```elixir\n\"my_org\"\n\n```","ref":"Aura.Common.html#t:org_name/0-examples"},{"type":"type","title":"See Also - Aura.Common.org_name/0","doc":"* `Aura.Orgs`","ref":"Aura.Common.html#t:org_name/0-see-also"},{"type":"type","title":"Aura.Common.package_name/0","doc":"Name of the package","ref":"Aura.Common.html#t:package_name/0"},{"type":"type","title":"Examples - Aura.Common.package_name/0","doc":"```elixir\n\"plug\"\n\n```","ref":"Aura.Common.html#t:package_name/0-examples"},{"type":"type","title":"Aura.Common.release_version/0","doc":"The version of a release","ref":"Aura.Common.html#t:release_version/0"},{"type":"type","title":"Examples - Aura.Common.release_version/0","doc":"```elixir\n\"1.2.3\"\n\n```","ref":"Aura.Common.html#t:release_version/0-examples"},{"type":"type","title":"Aura.Common.repo_name/0","doc":"The name of the repository","ref":"Aura.Common.html#t:repo_name/0"},{"type":"type","title":"Examples - Aura.Common.repo_name/0","doc":"```elixir\n\"hexpm\"\n\n```","ref":"Aura.Common.html#t:repo_name/0-examples"},{"type":"type","title":"Aura.Common.repo_url/0","doc":"A Hex compliant API endpoint","ref":"Aura.Common.html#t:repo_url/0"},{"type":"type","title":"Examples - Aura.Common.repo_url/0","doc":"```elixir\n\"https://hex.pm/api\"\n\"http://localhost:4000/api\"\n\n```","ref":"Aura.Common.html#t:repo_url/0-examples"},{"type":"type","title":"Aura.Common.start_page/0","doc":"When streaming, start at this page number. Default: 1","ref":"Aura.Common.html#t:start_page/0"},{"type":"function","title":"Aura.Common.stream_paginate/3","doc":"Implements Hex API's pagination mechanism by returning a `Stream.resource/3`\n\n\n\n###  Parameters \n  \n| Parameter | Description   |\n|--------|-----------------------|\n| *path*   | `t:api_path/0` |\n| *opts*   | option parameters used to modify requests |\n| *build_func*   | a function that takes in a map and returns a struct representing what's being paginated |","ref":"Aura.Common.html#stream_paginate/3"},{"type":"function","title":"Examples - Aura.Common.stream_paginate/3","doc":"```elixir\niex> alias Aura.Common\niex> alias Aura.Model.HexPackage\niex> opts = [repo_url: \"http://localhost:4000/api\", repo: \"hexpm\", page: 2, sort: :total_downloads]\niex> {path, opts} = Common.determine_path(opts, \"/packages\")\niex> packages = Common.stream_paginate(path, &HexPackage.build/1, opts)\niex> Enum.empty?(packages)\nfalse\n\n```","ref":"Aura.Common.html#stream_paginate/3-examples"},{"type":"type","title":"Aura.Common.username/0","doc":"A unique, human-readable ID for a user","ref":"Aura.Common.html#t:username/0"},{"type":"type","title":"Examples - Aura.Common.username/0","doc":"```elixir\n  \"camatcode\"\n\n```","ref":"Aura.Common.html#t:username/0-examples"},{"type":"module","title":"Aura.Model.Common","doc":"Common capabilities across all Aura models","ref":"Aura.Model.Common.html"},{"type":"module","title":"Resources - Aura.Model.Common","doc":"* Hex\n    * 📖 [Hex API Specifications](https://github.com/hexpm/specifications){:target=\"_blank\"}\n    * 👾 [Github: hexpm/hex_core](https://github.com/hexpm/hex_core){:target=\"_blank\"}\n    * 👾 [Github: hexpm/hexpm](https://github.com/hexpm/hexpm){:target=\"_blank\"}\n  * Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * ⚗️ [Elixir Form: camatcode](https://elixirforum.com/u/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    * 🦋️ [bsky: @ckcook.studiocms.io](https://bsky.app/profile/ckcook.studiocms.io){:target=\"_blank\"}","ref":"Aura.Model.Common.html#module-resources"},{"type":"type","title":"Aura.Model.Common.billing_active/0","doc":"Whether the repository is a billable entity","ref":"Aura.Model.Common.html#t:billing_active/0"},{"type":"type","title":"Aura.Model.Common.docs_html_url/0","doc":"URL with human-readable package/release documentation","ref":"Aura.Model.Common.html#t:docs_html_url/0"},{"type":"type","title":"Examples - Aura.Model.Common.docs_html_url/0","doc":"```elixir\n\"https://hexdocs.pm/aura/0.9.0/\"\n\n```","ref":"Aura.Model.Common.html#t:docs_html_url/0-examples"},{"type":"type","title":"Aura.Model.Common.html_url/0","doc":"URL with human-readable package/release information","ref":"Aura.Model.Common.html#t:html_url/0"},{"type":"type","title":"Examples - Aura.Model.Common.html_url/0","doc":"```elixir\n\"https://hex.pm/packages/aura/0.9.0\"\n\n```","ref":"Aura.Model.Common.html#t:html_url/0-examples"},{"type":"type","title":"Aura.Model.Common.inserted_at/0","doc":"`DateTime` for when the record was inserted into the database","ref":"Aura.Model.Common.html#t:inserted_at/0"},{"type":"type","title":"Examples - Aura.Model.Common.inserted_at/0","doc":"```elixir\n~U[2025-05-29 18:15:18.244790Z]\n\n```","ref":"Aura.Model.Common.html#t:inserted_at/0-examples"},{"type":"function","title":"Aura.Model.Common.prepare/1","doc":"Cleans and validates a map into something Aura models can easily build\n\n\n\n###  Parameters \n  \n| Parameter | Description   |\n|--------|-----------------------|\n| *m*   | A map to clean and validate |","ref":"Aura.Model.Common.html#prepare/1"},{"type":"type","title":"Aura.Model.Common.updated_at/0","doc":"`DateTime` for when the record was last modified in the database","ref":"Aura.Model.Common.html#t:updated_at/0"},{"type":"type","title":"Examples - Aura.Model.Common.updated_at/0","doc":"```elixir\n~U[2025-06-01 15:13:04.347130Z]\n\n```","ref":"Aura.Model.Common.html#t:updated_at/0-examples"},{"type":"type","title":"Aura.Model.Common.url/0","doc":"The URL required to perform operations on this record","ref":"Aura.Model.Common.html#t:url/0"},{"type":"type","title":"Examples - Aura.Model.Common.url/0","doc":"```elixir\n\"https://hex.pm/api/packages/aura/releases/0.9.0\"\n\n```","ref":"Aura.Model.Common.html#t:url/0-examples"},{"type":"module","title":"Aura.PackageTarUtil","doc":"A utility to read a release tar from a Hex-compliant API","ref":"Aura.PackageTarUtil.html"},{"type":"module","title":"Resources - Aura.PackageTarUtil","doc":"* Hex\n    * 📖 [Hex API Specifications](https://github.com/hexpm/specifications){:target=\"_blank\"}\n    * 👾 [Github: hexpm/hex_core](https://github.com/hexpm/hex_core){:target=\"_blank\"}\n    * 👾 [Github: hexpm/hexpm](https://github.com/hexpm/hexpm){:target=\"_blank\"}\n  * Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * ⚗️ [Elixir Form: camatcode](https://elixirforum.com/u/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    * 🦋️ [bsky: @ckcook.studiocms.io](https://bsky.app/profile/ckcook.studiocms.io){:target=\"_blank\"}","ref":"Aura.PackageTarUtil.html#module-resources"},{"type":"function","title":"Aura.PackageTarUtil.read_release_tar/1","doc":"Reads a release tar from a given file path","ref":"Aura.PackageTarUtil.html#read_release_tar/1"},{"type":"type","title":"Aura.PackageTarUtil.tar_contents/0","doc":"A mapping between entries of a tar and their bytes","ref":"Aura.PackageTarUtil.html#t:tar_contents/0"},{"type":"module","title":"Aura.Requester","doc":"Utility for making HTTP requests to a Hex-compliant API","ref":"Aura.Requester.html"},{"type":"module","title":"Resources - Aura.Requester","doc":"* Hex\n    * 📖 [Hex API Specifications](https://github.com/hexpm/specifications){:target=\"_blank\"}\n    * 👾 [Github: hexpm/hex_core](https://github.com/hexpm/hex_core){:target=\"_blank\"}\n    * 👾 [Github: hexpm/hexpm](https://github.com/hexpm/hexpm){:target=\"_blank\"}\n  * Contact the maintainer (he's happy to help!)\n    * 👾 [Github: camatcode](https://github.com/camatcode/){:target=\"_blank\"}\n    * ⚗️ [Elixir Form: camatcode](https://elixirforum.com/u/camatcode/){:target=\"_blank\"}\n    * 🐘 [Fediverse: @scrum_log@maston.social](https://mastodon.social/@scrum_log){:target=\"_blank\"}\n    * 🦋️ [bsky: @ckcook.studiocms.io](https://bsky.app/profile/ckcook.studiocms.io){:target=\"_blank\"}","ref":"Aura.Requester.html#module-resources"},{"type":"function","title":"Aura.Requester.delete/2","doc":"Makes a HTTP DELETE request","ref":"Aura.Requester.html#delete/2"},{"type":"function","title":"Aura.Requester.find_repo_url/1","doc":"Inspects given options, or the `Application.get_env/3` for\n  a Hex-compliant API URL","ref":"Aura.Requester.html#find_repo_url/1"},{"type":"function","title":"Aura.Requester.get/2","doc":"Makes a HTTP GET request","ref":"Aura.Requester.html#get/2"},{"type":"function","title":"Aura.Requester.hex_pm_url/0","doc":"Returns https://hex.pm/api","ref":"Aura.Requester.html#hex_pm_url/0"},{"type":"type","title":"Aura.Requester.http_method/0","doc":"The HTTP method to use for a given request","ref":"Aura.Requester.html#t:http_method/0"},{"type":"function","title":"Aura.Requester.post/2","doc":"Makes a HTTP POST request","ref":"Aura.Requester.html#post/2"},{"type":"function","title":"Aura.Requester.put/2","doc":"Makes a HTTP PUT request","ref":"Aura.Requester.html#put/2"},{"type":"function","title":"Aura.Requester.request/3","doc":"Makes a HTTP request","ref":"Aura.Requester.html#request/3"},{"type":"extras","title":"README","doc":"An ergonomic library for investigating the Hex.pm API","ref":"readme.html"},{"type":"extras","title":"Table of Contents - README","doc":"- [Installation](#installation)\n- [Configuration](#configuration)\n- [Smoke Test](#smoke-test)\n- [Implementation Overview](#implementation-overview)\n    - [Domains](#domains)\n- [Testing](#testing)\n- [FAQ](#faq)","ref":"readme.html#table-of-contents"},{"type":"extras","title":"Installation - README","doc":"Add `:aura` to your list of deps in `mix.exs`:\n\n```elixir\n{:aura, \"~> 1.0\"}\n```\n\nThen run `mix deps.get` to install Aura and its dependencies.","ref":"readme.html#installation"},{"type":"extras","title":"Configuration - README","doc":"```elixir\nconfig :aura,\n  # The hex-compliant backend for Aura to connect to\n  # This can also be passed in as an option to all service functions\n  # Default: https://hex.pm/api\n  # See \"Testing\" for other options\n  repo_url: System.get_env(\"AURA_REPO_URL\", \"http://localhost:4000/api\"),\n  # API secret payload to use when making requests from the hex-compliant backend\n  # This cannot be passed in as an option to service functions.\n  # Please: Don't put the actual secret payload as plain text in your code.\n  # Default: nil\n  api_key: System.get_env(\"HEX_API_KEY\")\n\n```","ref":"readme.html#configuration"},{"type":"extras","title":"Smoke Test - README","doc":"```elixir\n# Grab aura\n{:ok, package} = Aura.Packages.get_package(\"aura\")\nlatest_version = package.releases |> hd() |> Map.get(:version)\n# Grab aura's latest release\n{:ok, release} = Aura.Releases.get_release(\"aura\", latest_version)\n{:ok,\n %Aura.Model.HexRelease{\n   checksum: \"8fb6919a3cf545b10e09bc9b98169cca82468157a5e6b1ebd754e833934b02dd\",\n   configs: %{\n     \"erlang.mk\" => \"dep_aura = hex 0.9.1\",\n     \"mix.exs\" => \"{:aura, \\\"~> 0.9.1\\\"}\",\n     \"rebar.config\" => \"{aura, \\\"0.9.1\\\"}\"\n   },\n   docs_html_url: \"https://hexdocs.pm/aura/0.9.1/\",\n   has_docs: true,\n   html_url: \"https://hex.pm/packages/aura/0.9.1\",\n   inserted_at: ~U[2025-06-04 04:51:30.142335Z],\n   meta: %{elixir: \"~> 1.18\", app: \"aura\", build_tools: [\"mix\"]},\n   package_url: \"https://hex.pm/api/packages/aura\",\n   publisher: %{\n     url: \"https://hex.pm/api/users/camatcode\",\n     email: \"cam.cook.codes@gmail.com\",\n     username: \"camatcode\"\n   },\n   requirements: [\n     %{app: \"date_time_parser\", optional: false, requirement: \"~> 1.2.0\"},\n     %{app: \"proper_case\", optional: false, requirement: \"~> 1.3\"},\n     %{app: \"req\", optional: false, requirement: \"~> 0.5.10\"}\n   ],\n   retirement: nil,\n   updated_at: ~U[2025-06-04 04:51:33.602905Z],\n   version: \"0.9.1\",\n   url: \"https://hex.pm/api/packages/aura/releases/0.9.1\",\n   downloads: 0\n }}\n```","ref":"readme.html#smoke-test"},{"type":"extras","title":"Implementation Overview - README","doc":"","ref":"readme.html#implementation-overview"},{"type":"extras","title":"Domains - README","doc":"| Domain       | Hex API Controller                                                                                                          | Aura Equivalant | Implemented Actions                             | Notes                                       |\n|--------------|-----------------------------------------------------------------------------------------------------------------------------|-----------------|-------------------------------------------------|---------------------------------------------|\n| API Key      | [KeyController](https://github.com/hexpm/hexpm/blob/main/lib/hexpm_web/controllers/api/key_controller.ex)                   | `Aura.APIKeys`  | list, get, create, delete, delete all           | Can be scoped to an organization            |\n| Organization | [OrganizationController](https://github.com/hexpm/hexpm/blob/main/lib/hexpm_web/controllers/api/organization_controller.ex) | `Aura.Orgs`     | list, get, audit                                |                                             |\n| ∟ Org User   | [OrganizationUser](https://github.com/hexpm/hexpm/blob/main/lib/hexpm_web/controllers/api/organization_user_controller.ex)  | \"               | list, get, add, change role, remove             |                                             |\n| Package      | [PackageController](https://github.com/hexpm/hexpm/blob/main/lib/hexpm_web/controllers/api/package_controller.ex)           | `Aura.Packages` | stream packages, get, audit                     | Can be scoped to a repo                     |\n| ∟ Owner      | [OwnerController](https://github.com/hexpm/hexpm/blob/main/lib/hexpm_web/controllers/api/owner_controller.ex)               | \"               | list, get, add, remove                          | Can be scoped to a repo                     |\n| Release      | [ReleaseController](https://github.com/hexpm/hexpm/blob/main/lib/hexpm_web/controllers/api/release_controller.ex)           | `Aura.Releases` | publish, get, retire, un-retire, delete         | Can be scoped to a repo                     |\n| ∟ Doc        | [DocsController](https://github.com/hexpm/hexpm/blob/main/lib/hexpm_web/controllers/api/docs_controller.ex)                 | \"               | publish, get, delete                            | Can be scoped to a repo                     |\n| Repository   | [RepositoryController](https://github.com/hexpm/hexpm/blob/main/lib/hexpm_web/controllers/api/repository_controller.ex)     | `Aura.Repos`    | list, get                                       |                                             |\n| User         | [UserController](https://github.com/hexpm/hexpm/blob/main/lib/hexpm_web/controllers/api/user_controller.ex)                 | `Aura.Users`    | create, get, get current, reset password, audit | Read `create` docs carefully for ToS caveat |","ref":"readme.html#domains"},{"type":"extras","title":"Testing - README","doc":"> [!WARNING]\n> All Aura tests expect to connect to a local hex instance\n> and will **purposely crash** if it discovers it's testing against hex.pm.\n\nYou should be very mindful about issuing requests against a production hex API.\n\nTo make this easy, you can `docker compose up -d` from the root of this repository to launch a local instance\nof [hexpm/hexpm](https://github.com/camatcode/hex_tiny?tab=readme-ov-file#hex_beefy) and set the `repo_url`\nto http://localhost:4000/api in [Configuration](#configuration).\n\n```bash\n➜  docker compose up -d\n[+] Running 1/1\n ✔ Container hex_beefy  Started                                                                                  0.1s \n➜  curl http://localhost:4000/api | jq\n{\n  \"documentation_url\": \"http://docs.hexpm.apiary.io\",\n  \"key_url\": \"http://localhost:4000/api/keys/{name}\",\n  \"keys_url\": \"http://localhost:4000/api/keys\",\n  \"package_owners_url\": \"http://localhost:4000/api/packages/{name}/owners\",\n  \"package_release_url\": \"http://localhost:4000/api/packages/{name}/releases/{version}\",\n  \"package_url\": \"http://localhost:4000/api/packages/{name}\",\n  \"packages_url\": \"http://localhost:4000/api/packages\"\n}\n```","ref":"readme.html#testing"},{"type":"extras","title":"FAQ - README","doc":"> Why?\n\nI started this project while exploring all the Hex API does, had trouble understanding it all, so started documenting things as I found them, and wound up with an entire project.\n\nHere are some goals and motivations: \n\n1. Aura is meant to be friendly to Elixir folks.\n2. Aura's aim is to be [documented](https://hexdocs.pm/aura) *to hell and back*.\n3. The maintainer has larger plans that would use Aura as a base.","ref":"readme.html#faq"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}